"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPathChrome = exports.oneTab = exports.initLaunch = exports.PathSession = exports.initBrowser = void 0;
const puppeteer_extra_1 = __importDefault(require("puppeteer-extra"));
const ChromeLauncher = __importStar(require("chrome-launcher"));
const path = __importStar(require("path"));
const fs = __importStar(require("fs"));
const enum_1 = require("../model/enum");
const help_1 = require("../help");
const StealthPlugin = require('puppeteer-extra-plugin-stealth');
/**
 * Function to create a new tab in the browser instance
 * @param Browser - Browser instance to create a new tab
 * @returns - Returns a new tab or false if it fails
 */
async function initBrowser(Browser) {
    const wpage = await oneTab(Browser);
    if (wpage) {
        try {
            await wpage.setUserAgent(help_1.puppeteerConfig.useragentOverride);
            await wpage.setCacheEnabled(true);
            await wpage.goto(help_1.puppeteerConfig.whatsappUrl, {
                waitUntil: 'domcontentloaded',
            });
            wpage.on('pageerror', ({ message }) => {
                const erroLogType1 = message.includes('RegisterEffect is not a function');
                const erroLogType2 = message.includes('[Report Only]');
                if (erroLogType1 || erroLogType2) {
                    wpage.evaluate(() => {
                        localStorage.clear();
                        window.location.reload();
                    });
                }
            });
            Browser.userAgent();
            return wpage;
        }
        catch (_a) {
            return false;
        }
    }
    return false;
}
exports.initBrowser = initBrowser;
/**
 * Function to create a new session in the browser instance
 * @param options - Options to create a new session in the browser instance
 */
function PathSession(options) {
    options.mkdirFolderToken = options.mkdirFolderToken
        ? options.mkdirFolderToken
        : '';
    options.pathNameToken = options.pathNameToken ? options.pathNameToken : '';
    options.session = options.session ? options.session : '';
    const folderNameToken = path.join(path.resolve(process.cwd(), options.mkdirFolderToken, options.pathNameToken));
    if (!fs.existsSync(folderNameToken)) {
        fs.mkdirSync(folderNameToken, {
            recursive: true,
        });
    }
    const pathSession = path.join(path.resolve(process.cwd(), options.mkdirFolderToken, options.pathNameToken, options.session));
    if (!fs.existsSync(pathSession)) {
        fs.mkdirSync(pathSession, {
            recursive: true,
        });
    }
    fs.chmodSync(folderNameToken, '777');
    fs.chmodSync(pathSession, '777');
    if (options && options.puppeteerOptions) {
        options.puppeteerOptions.userDataDir = pathSession;
    }
    help_1.puppeteerConfig.chromiumArgs.push(`--user-data-dir=${pathSession}`);
}
exports.PathSession = PathSession;
/**
 * Function to create a new session in the browser instance
 * @param options - Options to create a new session in the browser instance
 * @param ev - Event to emit status
 * @returns - Returns a new browser instance or false if it fails
 */
async function initLaunch(options, ev) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
    PathSession(options);
    if (((_a = options.puppeteerOptions) === null || _a === void 0 ? void 0 : _a.executablePath) === 'useChrome') {
        const chromePath = getPathChrome();
        options.puppeteerOptions.executablePath = chromePath;
    }
    if (((_b = options.puppeteerOptions) === null || _b === void 0 ? void 0 : _b.downloadChromium) &&
        ((_c = options.puppeteerOptions) === null || _c === void 0 ? void 0 : _c.chromiumVersion) &&
        ((_d = options.puppeteerOptions) === null || _d === void 0 ? void 0 : _d.executablePath) === 'useChromium') {
        const browserFetcher = puppeteer_extra_1.default.createBrowserFetcher({});
        let init = true;
        ev.emitStatusFind({
            error: false,
            text: 'Await download Chromium',
            status: enum_1.TypeStatusFind.chromium,
            statusFind: 'browser',
            onType: enum_1.OnMode.connection,
            session: options.session,
        });
        await browserFetcher
            .download((_e = options.puppeteerOptions) === null || _e === void 0 ? void 0 : _e.chromiumVersion, (downloadedByte, totalBytes) => {
            if (init) {
                ev.emitStatusFind({
                    error: false,
                    text: 'Checking the total bytes to download!',
                    status: enum_1.TypeStatusFind.chromium,
                    statusFind: 'browser',
                    onType: enum_1.OnMode.connection,
                    session: options.session,
                });
                if (totalBytes) {
                    ev.emitStatusFind({
                        error: false,
                        text: `Total Bytes ${totalBytes}`,
                        status: enum_1.TypeStatusFind.chromium,
                        statusFind: 'browser',
                        onType: enum_1.OnMode.connection,
                        session: options.session,
                    });
                }
                init = true;
            }
            if (downloadedByte) {
                ev.emitStatusFind({
                    error: false,
                    text: `Total Bytes: ${totalBytes} download: ${downloadedByte}`,
                    status: enum_1.TypeStatusFind.chromium,
                    statusFind: 'browser',
                    onType: enum_1.OnMode.connection,
                    session: options.session,
                });
            }
            if (downloadedByte === totalBytes) {
                ev.emitStatusFind({
                    error: false,
                    text: `Extract files... await...`,
                    status: enum_1.TypeStatusFind.chromium,
                    statusFind: 'browser',
                    onType: enum_1.OnMode.connection,
                    session: options.session,
                });
            }
        })
            .then((revisionInfo) => {
            var _a, _b;
            if ((_a = options.puppeteerOptions) === null || _a === void 0 ? void 0 : _a.executablePath) {
                options.puppeteerOptions.executablePath =
                    revisionInfo === null || revisionInfo === void 0 ? void 0 : revisionInfo.executablePath;
                ev.emitStatusFind({
                    error: false,
                    text: `download completed, path: ${revisionInfo === null || revisionInfo === void 0 ? void 0 : revisionInfo.executablePath}`,
                    status: enum_1.TypeStatusFind.chromium,
                    statusFind: 'browser',
                    onType: enum_1.OnMode.connection,
                    session: options.session,
                });
            }
            if ((_b = options.puppeteerOptions) === null || _b === void 0 ? void 0 : _b.args) {
                options.puppeteerOptions.args.push(`--single-process`);
            }
        })
            .catch((e) => {
            ev.emitStatusFind({
                error: true,
                text: `Error chromium`,
                status: enum_1.TypeStatusFind.chromium,
                statusFind: 'browser',
                onType: enum_1.OnMode.connection,
                session: options.session,
                result: e,
            });
        });
    }
    if (!((_f = options.puppeteerOptions) === null || _f === void 0 ? void 0 : _f.executablePath)) {
        return false;
    }
    try {
        puppeteer_extra_1.default.use(StealthPlugin());
        return await puppeteer_extra_1.default.launch({
            headless: (_g = options.puppeteerOptions) === null || _g === void 0 ? void 0 : _g.headless,
            args: (_h = options.puppeteerOptions) === null || _h === void 0 ? void 0 : _h.args,
            executablePath: (_j = options.puppeteerOptions) === null || _j === void 0 ? void 0 : _j.executablePath,
            userDataDir: (_k = options.puppeteerOptions) === null || _k === void 0 ? void 0 : _k.userDataDir,
            devtools: (_l = options.puppeteerOptions) === null || _l === void 0 ? void 0 : _l.devtools,
        });
    }
    catch (e) {
        return false;
    }
}
exports.initLaunch = initLaunch;
/**
 * Function to create a new tab in the browser instance
 * @param Browser - Browser instance to create a new tab
 * @returns - Returns a new tab or false if it fails
 */
async function oneTab(Browser) {
    try {
        const page = await Browser.pages();
        if (page.length)
            return page[0];
        return await Browser.newPage();
    }
    catch (_a) {
        return false;
    }
}
exports.oneTab = oneTab;
function getPathChrome() {
    try {
        const chromeInstalations = ChromeLauncher.Launcher.getInstallations();
        return chromeInstalations[0];
    }
    catch (_a) {
        return undefined;
    }
}
exports.getPathChrome = getPathChrome;
//# sourceMappingURL=browser.js.map