"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initServer = void 0;
const interface_1 = require("../model/interface");
const browser_1 = require("./browser");
const webpack_1 = require("../inject/webpack");
const layes_1 = require("./layes");
const enum_1 = require("../model/enum");
const help_1 = require("../help");
const check_up_to_date_1 = require("./check-up-to-date");
const ev = new layes_1.CallbackOnStatus();
/**
 * Function to create a new session in the browser instance
 * @param options - Options to create a new session in the browser instance
 * @returns - Returns a new session in the browser instance
 */
async function initServer(options) {
    return new Promise(async (resolve) => {
        resolve(ev);
        const mergeOptionsDefault = Object.assign(Object.assign({}, interface_1.defaultConfig), options);
        if (!!(options === null || options === void 0 ? void 0 : options.puppeteerOptions)) {
            mergeOptionsDefault.puppeteerOptions = Object.assign(Object.assign({}, interface_1.defaultConfig.puppeteerOptions), options.puppeteerOptions);
        }
        if (!!mergeOptionsDefault.session && mergeOptionsDefault.session.length) {
            const sessionName = mergeOptionsDefault.session;
            const replaceSession = sessionName.replace(/[^0-9a-zA-Zs]/g, '');
            if (replaceSession.length) {
                mergeOptionsDefault.session = replaceSession;
            }
            else {
                mergeOptionsDefault.session = interface_1.defaultConfig.session;
            }
        }
        if (mergeOptionsDefault.updatesLog) {
            await (0, check_up_to_date_1.checkUpdates)();
        }
        ev.emitStatusFind({
            error: false,
            text: 'Starting browser...',
            status: enum_1.TypeStatusFind.initBrowser,
            statusFind: 'browser',
            onType: enum_1.OnMode.connection,
            session: mergeOptionsDefault.session,
        });
        const wpage = await (0, browser_1.initLaunch)(mergeOptionsDefault, ev);
        if (typeof wpage !== 'boolean') {
            ev.emitStatusFind({
                error: false,
                text: 'Opening whatsapp page!',
                status: enum_1.TypeStatusFind.initWhatsapp,
                statusFind: 'browser',
                onType: enum_1.OnMode.connection,
                session: mergeOptionsDefault.session,
            });
            const page = await (0, browser_1.initBrowser)(wpage);
            if (typeof page !== 'boolean') {
                ev.emitStatusFind({
                    error: false,
                    page: page,
                    statusFind: 'page',
                    onType: enum_1.OnMode.connection,
                    session: mergeOptionsDefault.session,
                });
                await (0, help_1.sleep)(100);
                ev.emitStatusFind({
                    error: false,
                    text: 'Website accessed successfully',
                    status: enum_1.TypeStatusFind.openedWhatsapp,
                    statusFind: 'browser',
                    onType: enum_1.OnMode.connection,
                    session: mergeOptionsDefault.session,
                });
                const client = new webpack_1.WebPack(page, wpage, mergeOptionsDefault, ev);
                (0, help_1.checkingCloses)(wpage, () => {
                    ev.emitStatusFind({
                        error: true,
                        text: 'The browser has closed',
                        status: enum_1.TypeStatusFind.browserClosed,
                        statusFind: 'browser',
                        onType: enum_1.OnMode.connection,
                        session: mergeOptionsDefault.session,
                    });
                }).catch(() => {
                    console.log('The client has been closed');
                });
                ev.on(enum_1.OnMode.interfaceChange, async (interFace) => {
                    try {
                        client.cancelAutoClose();
                        if (interFace.result.mode === enum_1.InterfaceMode.MAIN &&
                            interFace.result.info === 'NORMAL') {
                            ev.emitStatusFind({
                                error: false,
                                connect: true,
                                onType: enum_1.OnMode.connection,
                                session: mergeOptionsDefault.session,
                                client: client,
                            });
                        }
                        if (interFace.result.mode === enum_1.InterfaceMode.QR &&
                            interFace.result.info === 'NORMAL') {
                            ev.emitStatusFind({
                                error: false,
                                qrcode: interFace.result.info,
                                onType: enum_1.OnMode.connection,
                                session: mergeOptionsDefault.session,
                            });
                            await client.qrCodeScan();
                        }
                    }
                    catch (_a) { }
                });
            }
            else {
                ev.emitStatusFind({
                    error: true,
                    text: 'Error open whatzapp',
                    status: enum_1.TypeStatusFind.noOpenWhatzapp,
                    statusFind: 'browser',
                    onType: enum_1.OnMode.connection,
                    session: mergeOptionsDefault.session,
                });
                wpage.close();
            }
        }
        else {
            ev.emitStatusFind({
                error: true,
                text: 'Error open browser...',
                status: enum_1.TypeStatusFind.noOpenBrowser,
                statusFind: 'browser',
                onType: enum_1.OnMode.connection,
                session: mergeOptionsDefault.session,
            });
        }
    });
}
exports.initServer = initServer;
//# sourceMappingURL=init.js.map