"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SenderLayer = void 0;
const retriever_layer_1 = require("./retriever.layer");
const help_1 = require("../../help");
const enum_1 = require("../../model/enum/");
const help_2 = require("../../help");
const path = __importStar(require("path"));
class SenderLayer extends retriever_layer_1.RetrieverLayer {
    constructor(page, browser, options, ev) {
        super(page, browser, options, ev);
        this.page = page;
        this.browser = browser;
        this.options = options;
        this.ev = ev;
    }
    /**
     * Sends image message
     * @param to Chat id
     * @param filePath File path or http link
     */
    async sendImage(to, filePath, options = {}) {
        return new Promise(async (resolve, reject) => {
            Object.assign(options, { type: enum_1.FunctionType.sendImage });
            let base64 = await (0, help_2.downloadFileToBase64)(filePath, [
                'image/gif',
                'image/png',
                'image/jpg',
                'image/jpeg',
                'image/webp',
            ]);
            if (!base64) {
                base64 = await (0, help_2.fileToBase64)(filePath);
            }
            if (!base64) {
                return reject({
                    error: true,
                    to: to,
                    text: 'No such file or directory, open "' + filePath + '"',
                });
            }
            if (!options.filename) {
                options.filename = path.basename(filePath);
            }
            let mimeType = (0, help_1.base64MimeType)(base64);
            if (!mimeType) {
                return reject({
                    error: true,
                    to: to,
                    text: 'Invalid base64!',
                });
            }
            if (!mimeType.includes('image')) {
                return reject({
                    error: true,
                    to: to,
                    text: 'Not an image, allowed formats gif, png, jpg, jpeg and webp',
                });
            }
            options.filename = (0, help_2.filenameFromMimeType)(options.filename, mimeType);
            const result = await this.page
                .evaluate(({ to, base64, options }) => {
                return API.sendMessage(to, base64, options);
            }, { to, base64, options })
                .catch();
            if (result.erro == true) {
                return reject(result);
            }
            else {
                return resolve(result);
            }
        });
    }
    /**
     * Sends image message base64
     * @param to Chat id
     * @param base64 File path, http link or base64Encoded
     */
    async sendImageFromBase64(to, base64, options = {}) {
        return new Promise(async (resolve, reject) => {
            Object.assign(options, { type: enum_1.FunctionType.sendImageFromBase64 });
            let mimeType = (0, help_1.base64MimeType)(base64);
            if (!mimeType) {
                return reject({
                    error: true,
                    to: to,
                    text: 'Invalid base64!',
                });
            }
            if (!mimeType.includes('image')) {
                return reject({
                    error: true,
                    to: to,
                    text: 'Not an image, allowed formats gif, png, jpg, jpeg and webp',
                });
            }
            const result = await this.page
                .evaluate(({ to, base64, options }) => {
                return API.sendMessage(to, base64, options);
            }, { to, base64, options })
                .catch();
            if (result.erro == true) {
                return reject(result);
            }
            else {
                return resolve(result);
            }
        });
    }
    /**
     * Sends file from path
     * @param to Chat id
     * @param filePath File path
     */
    async sendFile(to, filePath, options = {}) {
        return new Promise(async (resolve, reject) => {
            Object.assign(options, { type: enum_1.FunctionType.sendFile });
            let base64 = await (0, help_2.downloadFileToBase64)(filePath);
            if (!base64) {
                base64 = await (0, help_2.fileToBase64)(filePath);
            }
            if (!base64) {
                return reject({
                    error: true,
                    to: to,
                    text: 'No such file or directory, open "' + filePath + '"',
                });
            }
            if (!options.filename && typeof options.filename !== 'string') {
                options.filename = path.basename(filePath);
            }
            let mimeType = (0, help_1.base64MimeType)(base64);
            if (!mimeType) {
                return reject({
                    error: true,
                    to: to,
                    text: 'Invalid base64!',
                });
            }
            options.filename = (0, help_2.filenameFromMimeType)(options.filename, mimeType);
            const result = await this.page
                .evaluate(({ to, base64, options }) => {
                return API.sendMessage(to, base64, options);
            }, { to, base64, options })
                .catch();
            if (result.erro == true) {
                return reject(result);
            }
            else {
                return resolve(result);
            }
        });
    }
    /**
     * Sends a text message to given chat
     * @param to chat id: xxxxx@us.c
     * @param body text message
     */
    sendText(to, body, options = {}) {
        return new Promise(async (resolve, reject) => {
            Object.assign(options, { type: enum_1.FunctionType.sendText });
            const result = await this.page
                .evaluate(({ to, body, options }) => {
                return API.sendMessage(to, body, options);
            }, { to, body, options })
                .catch();
            if (result.erro == true) {
                return reject(result);
            }
            else {
                return resolve(result);
            }
        });
    }
    /**
     * Send audio base64
     * @param to Chat id
     * @param base64 base64 data
     */
    async sendAudioBase64(to, base64, options = {}) {
        return new Promise(async (resolve, reject) => {
            Object.assign(options, { type: enum_1.FunctionType.sendAudioBase64 });
            const mimeType = (0, help_1.base64MimeType)(base64);
            if (!mimeType) {
                return reject({
                    error: true,
                    to: to,
                    text: 'Invalid base64!',
                });
            }
            if (!mimeType || mimeType.includes('audio/mpeg')) {
                const result = await this.page
                    .evaluate(({ to, base64, options }) => {
                    return API.sendMessage(to, base64, options);
                }, { to, base64, options })
                    .catch();
                if (result.erro == true) {
                    return reject(result);
                }
                else {
                    return resolve(result);
                }
            }
            else {
                return reject({
                    error: true,
                    to: to,
                    text: 'Use the MP3 format to be able to send an audio!',
                });
            }
        });
    }
    /**
     * Send audio file
     * @param to Chat id
     * @param filePath Path file
     */
    async sendAudio(to, filePath, options = {}) {
        return new Promise(async (resolve, reject) => {
            Object.assign(options, { type: enum_1.FunctionType.sendAudio });
            let base64 = await (0, help_2.downloadFileToBase64)(filePath, [
                'audio/mpeg',
            ]);
            if (!base64) {
                base64 = await (0, help_2.fileToBase64)(filePath);
            }
            if (!base64) {
                return reject({
                    error: true,
                    to: to,
                    text: 'No such file or directory, open "' + filePath + '"',
                });
            }
            const mimeInfo = (0, help_1.base64MimeType)(base64);
            if (!mimeInfo || mimeInfo.includes('audio/mpeg')) {
                const result = await this.page
                    .evaluate(({ to, base64, options }) => {
                    return API.sendMessage(to, base64, options);
                }, { to, base64, options })
                    .catch();
                if (result.erro == true) {
                    return reject(result);
                }
                else {
                    return resolve(result);
                }
            }
            else {
                return reject({
                    error: true,
                    to: to,
                    text: 'Use the MP3 format to be able to send an audio!',
                });
            }
        });
    }
    /**
     * Send messages
     * @param sendOptions Send options
     */
    async sendMessage(sendOptions) {
        return new Promise(async (resolve, reject) => {
            const to = sendOptions.to, body = sendOptions.body, options = sendOptions.options;
            if (!Object.values(enum_1.FunctionType).includes(options.type)) {
                return reject({
                    error: true,
                    text: `pass the message type, examples: ${Object.values(enum_1.FunctionType).join(', ')}`,
                });
            }
            if (options.type === enum_1.FunctionType.sendFile ||
                options.type === enum_1.FunctionType.sendImage) {
                this.sendFile(to, body, options)
                    .then((e) => {
                    return resolve(e);
                })
                    .catch((e) => {
                    return reject(e);
                });
            }
            if (options.type === enum_1.FunctionType.sendAudioBase64) {
                this.sendAudioBase64(to, body, options)
                    .then((e) => {
                    return resolve(e);
                })
                    .catch((e) => {
                    return reject(e);
                });
            }
            if (options.type === enum_1.FunctionType.sendImageFromBase64) {
                this.sendImageFromBase64(to, body, options)
                    .then((e) => {
                    return resolve(e);
                })
                    .catch((e) => {
                    return reject(e);
                });
            }
            if (options.type === enum_1.FunctionType.sendAudio) {
                this.sendAudio(to, body, options)
                    .then((e) => {
                    return resolve(e);
                })
                    .catch((e) => {
                    return reject(e);
                });
            }
            if (options.type === enum_1.FunctionType.sendText) {
                this.sendText(to, body, options)
                    .then((e) => {
                    return resolve(e);
                })
                    .catch((e) => {
                    return reject(e);
                });
            }
        });
    }
}
exports.SenderLayer = SenderLayer;
//# sourceMappingURL=sender.layes.js.map