"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Whatsapp = void 0;
const scraping_layes_1 = require("./scraping.layes");
const help_1 = require("../../help");
const axios_1 = __importDefault(require("axios"));
class Whatsapp extends scraping_layes_1.Scraping {
    constructor(page, browser, options, ev) {
        super(page, browser, options, ev);
        this.page = page;
        this.browser = browser;
        this.options = options;
        this.ev = ev;
    }
    /**
     * Decrypts message file
     * @param message Message object
     * @returns Decrypted file buffer (null otherwise)
     */
    async decryptFile(message) {
        const options = (0, help_1.makeOptions)(help_1.puppeteerConfig.useragentOverride);
        message.clientUrl =
            message.clientUrl !== undefined
                ? message.clientUrl
                : message.deprecatedMms3Url;
        if (!message.clientUrl) {
            throw new Error('message is missing critical data needed to download the file.');
        }
        let haventGottenImageYet = true, res;
        try {
            while (haventGottenImageYet) {
                res = await axios_1.default.get(message.clientUrl.trim(), options);
                if (res.status == 200) {
                    haventGottenImageYet = false;
                }
                else {
                    await (0, help_1.sleep)(2000);
                }
            }
        }
        catch (error) {
            console.error(error);
            throw 'Error trying to download the file.';
        }
        const buff = Buffer.from(res.data, 'binary');
        return (0, help_1.magix)(buff, message.mediaKey, message.type.toUpperCase(), message.size);
    }
}
exports.Whatsapp = Whatsapp;
//# sourceMappingURL=whatsapp.js.map