/******/ (() => { // webpackBootstrap
/******/ 	"use strict";
/******/ 	var __webpack_modules__ = ({

/***/ "./functions/add-participant.js":
/*!**************************************!*\
  !*** ./functions/add-participant.js ***!
  \**************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   addParticipant: () => (/* binding */ addParticipant)
/* harmony export */ });
/**
 * Parameters for adding a participant to the group
 * @param {string} groupId group number
 * @param {(Array| String)} contactsId contact number
 */
async function addParticipant(groupId, contactsId) {
  const nameFunc = new Error().stack
    .match(/at (.*?) /)[1]
    .replace('Object.', '');
  if (!Array.isArray(contactsId)) {
    contactsId = [contactsId];
  }
  const chatGroup = Store.Chat.get(groupId);
  if (!chatGroup) {
    return API.scope(null, true, 404, `group not found: ${groupId}`);
  }
  const contacts = await Promise.all(contactsId.map((c) => API.sendExist(c)));
  const checkErro = contacts.filter((e) => e.erro === true)[0];

  if (checkErro && checkErro.status === 404) {
    if (!checkErro.erro) {
      checkErro.erro = true;
    }
    return checkErro;
  }

  try {
    await window.Store.Participants.addParticipants(chatGroup, contacts);
    return API.scope(
      groupId,
      false,
      200,
      `contact(s) successfully added!`,
      nameFunc,
      contacts.id
    );
  } catch {
    return API.scope(
      groupId,
      true,
      400,
      `could not add a participant`,
      nameFunc,
      contacts.id
    );
  }
}


/***/ }),

/***/ "./functions/create-group.js":
/*!***********************************!*\
  !*** ./functions/create-group.js ***!
  \***********************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   createGroup: () => (/* binding */ createGroup)
/* harmony export */ });
/**
 * Parameters for creating a group
 * @param {string} name name group
 * @param {(array|string)} contactsId group contact
 */
async function createGroup(name, contactsId) {
  const nameFunc = new Error().stack
    .match(/at (.*?) /)[1]
    .replace('Object.', '');
  if (typeof name !== 'string' || !name.length) {
    return API.scope(null, true, 404, 'enter the name variable as an string');
  }

  if (!Array.isArray(contactsId)) {
    contactsId = [contactsId];
  }

  const chat = await Promise.all(contactsId.map((c) => API.sendExist(c)));
  const checkErro = chat.filter((e) => e.erro === true)[0];

  if (checkErro && checkErro.status === 404) {
    if (!checkErro.erro) {
      checkErro.erro = true;
    }
    return checkErro;
  }

  const filterContact = chat.filter((c) => !c.erro && c.isUser);

  try {
    const result = await window.Store.createGroup(
      name,
      undefined,
      undefined,
      filterContact
    );
    return API.scope(
      filterContact.id,
      false,
      result,
      'group created successfully',
      nameFunc,
      name
    );
  } catch {
    return API.scope(
      filterContact.id,
      true,
      400,
      'error creating group',
      nameFunc,
      name
    );
  }
}


/***/ }),

/***/ "./functions/get-all-chats.js":
/*!************************************!*\
  !*** ./functions/get-all-chats.js ***!
  \************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   getAllChats: () => (/* binding */ getAllChats)
/* harmony export */ });
/**
 * Function to get all chats
 * @returns - Array of chats
 */
const getAllChats = async () => {
  const fromwWid = await Store.MaybeMeUser.getMaybeMeUser();
  if (fromwWid) {
    const idUser = await API.returnChat(fromwWid._serialized);
    if (idUser && idUser.status !== 404) {
      const chats = Store.Chat.map((chat) => API.serializeChatObj(chat));
      return chats;
    }
  }
  return false;
};


/***/ }),

/***/ "./functions/get-all-contacts.js":
/*!***************************************!*\
  !*** ./functions/get-all-contacts.js ***!
  \***************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   getAllContacts: () => (/* binding */ getAllContacts)
/* harmony export */ });
/**
 * returns a list of contacts
 * @returns contacts
 */
const getAllContacts = function () {
  const filterIsContact = Store.Contact._models.filter(
    (e) => e.isAddressBookContact
  );
  return filterIsContact.map((contact) => WAPI._serializeContactObj(contact));
};


/***/ }),

/***/ "./functions/get-contact.js":
/*!**********************************!*\
  !*** ./functions/get-contact.js ***!
  \**********************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   getContact: () => (/* binding */ getContact)
/* harmony export */ });
/**
 * Function to get contact by id
 * @param {*} id
 * @returns
 */
const getContact = (id) => {
  const found = Store.Contact.get(id);
  if (found) {
    return API.serializeContactObj(found);
  }
  return false;
};


/***/ }),

/***/ "./functions/get-host.js":
/*!*******************************!*\
  !*** ./functions/get-host.js ***!
  \*******************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   getHost: () => (/* binding */ getHost)
/* harmony export */ });
/**
 * Get information from the connected number
 */
async function getHost() {
  return new Promise(async (resolve, reject) => {
    try {
      const fromwWid = await Store.MaybeMeUser.getMaybeMeUser();
      if (fromwWid) {
        const infoUser = await Store.Contacts.ContactCollection.get(
          fromwWid._serialized
        );
        if (infoUser) {
          const result = await API.serializeMeObj(infoUser);
          return resolve(result);
        }
      }
    } catch (error) {
      reject(error);
    }
  });
}


/***/ }),

/***/ "./functions/get-wa-version.js":
/*!*************************************!*\
  !*** ./functions/get-wa-version.js ***!
  \*************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   getWAVersion: () => (/* binding */ getWAVersion)
/* harmony export */ });
/**
 * Returns the current version of the WhatsApp Web API
 * @returns
 */
const getWAVersion = () => {
  return window.Debug.VERSION;
};


/***/ }),

/***/ "./functions/help/check-chat-exist.js":
/*!********************************************!*\
  !*** ./functions/help/check-chat-exist.js ***!
  \********************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   checkChatExist: () => (/* binding */ checkChatExist)
/* harmony export */ });
/**
 * Function to check if a number is registered on WhatsApp chat
 * @param {*} id - The phone number
 * @returns - Return the status of the number
 */
const checkChatExist = async (id) => {
  try {
    const chat = await Store.Chat.find(id);
    if (chat?.chatEntryPoint === 'Chatlist') {
      return chat.id;
    }
  } catch {
    return false;
  }
};


/***/ }),

/***/ "./functions/help/check-number-status.js":
/*!***********************************************!*\
  !*** ./functions/help/check-number-status.js ***!
  \***********************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   checkNumberStatus: () => (/* binding */ checkNumberStatus)
/* harmony export */ });
/**
 * Function to check if a number is registered on WhatsApp
 * @param {*} id - The phone number
 * @param {*} conn - Check if the connection is connected
 * @returns {Promise<Object>} - Return the status of the number
 */
const checkNumberStatus = async (id, conn = false) => {
  return new Promise(async (resolve, reject) => {
    try {
      const err = {
        error: 404,
      };
      const connection =
        Store && Store.State && Store.State.Socket && Store.State.Socket.state
          ? Store.State.Socket.state
          : '';

      const checkType = API.sendCheckType(id);
      if (!!checkType && checkType.status === 404) {
        Object.assign(err, {
          text: checkType.text,
          numberExists: null,
        });
        throw err;
      }

      if (conn === true) {
        if (connection !== 'CONNECTED') {
          Object.assign(err, {
            text: 'No connection with WhatsApp',
            connection: connection,
            numberExists: null,
          });
          throw err;
        }
      }

      const chat = await API.checkChatExist(id);
      if (chat) {
        const data = {
          status: 200,
          numberExists: true,
          id: chat,
          error: false,
          checkNumberStatus: false,
        };
        return resolve(data);
      }

      const lid = await API.getChat(id);
      if (lid) {
        return await Store.checkNumber
          .queryWidExists(lid.id)
          .then((result) => {
            if (!!result && typeof result === 'object') {
              const data = {
                status: 200,
                numberExists: true,
                id: result.wid,
                error: false,
                checkNumberStatus: true,
              };
              return resolve(data);
            }
            Object.assign(err, {
              connection: connection,
              numberExists: false,
              text: `The number does not exist`,
            });
            throw err;
          })
          .catch((err) => {
            if (err.text) {
              throw err;
            }
            Object.assign(err, {
              connection: connection,
              numberExists: false,
              text: err,
              checkNumberStatus: true,
            });
            throw err;
          });
      } else {
        Object.assign(err, {
          connection: connection,
          numberExists: false,
        });
        throw err;
      }
    } catch (e) {
      const scope = {
        status: e.error,
        text: e.text,
        numberExists: e.numberExists,
        connection: e.connection,
        error: true,
      };
      reject(scope);
    }
  });
};


/***/ }),

/***/ "./functions/help/get-chat.js":
/*!************************************!*\
  !*** ./functions/help/get-chat.js ***!
  \************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   getChat: () => (/* binding */ getChat)
/* harmony export */ });
/**
 * building a chat number
 * @param {string} chatId Contact number
 * @returns {(Object|undefined)}
 */
const getChat = async (chatId) => {
  if (!chatId) return false;

  chatId = typeof chatId == 'string' ? chatId : chatId._serialized;
  let found = window.Store.Chat.get(chatId);

  if (!found) {
    if (Store.CheckWid.validateWid(chatId)) {
      const ConstructChat = new window.Store.UserConstructor(chatId, {
        intentionallyUsePrivateConstructor: !0,
      });
      const chatWid = new Store.WidFactory.createWid(chatId);
      await Store.Chat.add(
        {
          createdLocally: true,
          id: chatWid,
        },
        {
          merge: true,
        }
      );
      found = Store.Chat.find(ConstructChat) || false;
    }
  }
  if (found) {
    found.sendMessage = found.sendMessage
      ? found.sendMessage
      : function () {
          return window.Store.sendMessage.apply(this, arguments);
        };
  }
  return found;
};


/***/ }),

/***/ "./functions/help/get-mew-id.js":
/*!**************************************!*\
  !*** ./functions/help/get-mew-id.js ***!
  \**************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   getNewId: () => (/* binding */ getNewId)
/* harmony export */ });
/**
 * create a random id with 16 characters
 * @returns {string} returns a new id of a new message
 */
function getNewId() {
  let text = '';
  const possible =
    'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
  for (var i = 0; i < 16; i++)
    text += possible.charAt(Math.floor(Math.random() * possible.length));
  return text;
}


/***/ }),

/***/ "./functions/help/get-new-message.js":
/*!*******************************************!*\
  !*** ./functions/help/get-new-message.js ***!
  \*******************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   getNewMessageId: () => (/* binding */ getNewMessageId)
/* harmony export */ });
async function getNewMessageId(chatId) {
  const chat = await window.API.sendExist(chatId);
  if (chat.id) {
    const newMsgId = new Object();
    newMsgId.fromMe = true;
    newMsgId.id = await window.API.getNewId().toUpperCase();
    newMsgId.remote = new window.Store.WidFactory.createWid(
      chat.id._serialized
    );
    newMsgId._serialized = `${newMsgId.fromMe}_${newMsgId.remote}_${newMsgId.id}`;
    const Msgkey = new window.Store.MsgKey(newMsgId);
    return Msgkey;
  } else {
    return false;
  }
}


/***/ }),

/***/ "./functions/help/index.js":
/*!*********************************!*\
  !*** ./functions/help/index.js ***!
  \*********************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   checkChatExist: () => (/* reexport safe */ _check_chat_exist__WEBPACK_IMPORTED_MODULE_3__.checkChatExist),
/* harmony export */   checkNumberStatus: () => (/* reexport safe */ _check_number_status__WEBPACK_IMPORTED_MODULE_6__.checkNumberStatus),
/* harmony export */   getChat: () => (/* reexport safe */ _get_chat__WEBPACK_IMPORTED_MODULE_0__.getChat),
/* harmony export */   getNewId: () => (/* reexport safe */ _get_mew_id__WEBPACK_IMPORTED_MODULE_1__.getNewId),
/* harmony export */   getNewMessageId: () => (/* reexport safe */ _get_new_message__WEBPACK_IMPORTED_MODULE_2__.getNewMessageId),
/* harmony export */   isMD: () => (/* reexport safe */ _is_md__WEBPACK_IMPORTED_MODULE_7__.isMD),
/* harmony export */   returnChat: () => (/* reexport safe */ _return_to_chat__WEBPACK_IMPORTED_MODULE_8__.returnChat),
/* harmony export */   scope: () => (/* reexport safe */ _scope__WEBPACK_IMPORTED_MODULE_9__.scope),
/* harmony export */   sendCheckType: () => (/* reexport safe */ _send_check_type__WEBPACK_IMPORTED_MODULE_5__.sendCheckType),
/* harmony export */   sendExist: () => (/* reexport safe */ _send_exist__WEBPACK_IMPORTED_MODULE_4__.sendExist)
/* harmony export */ });
/* harmony import */ var _get_chat__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./get-chat */ "./functions/help/get-chat.js");
/* harmony import */ var _get_mew_id__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./get-mew-id */ "./functions/help/get-mew-id.js");
/* harmony import */ var _get_new_message__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./get-new-message */ "./functions/help/get-new-message.js");
/* harmony import */ var _check_chat_exist__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./check-chat-exist */ "./functions/help/check-chat-exist.js");
/* harmony import */ var _send_exist__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./send-exist */ "./functions/help/send-exist.js");
/* harmony import */ var _send_check_type__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./send-check-type */ "./functions/help/send-check-type.js");
/* harmony import */ var _check_number_status__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./check-number-status */ "./functions/help/check-number-status.js");
/* harmony import */ var _is_md__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./is-md */ "./functions/help/is-md.js");
/* harmony import */ var _return_to_chat__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./return-to-chat */ "./functions/help/return-to-chat.js");
/* harmony import */ var _scope__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./scope */ "./functions/help/scope.js");














/***/ }),

/***/ "./functions/help/is-md.js":
/*!*********************************!*\
  !*** ./functions/help/is-md.js ***!
  \*********************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   isMD: () => (/* binding */ isMD)
/* harmony export */ });
async function isMD() {
  if (
    !window.localStorage.getItem('WASecretBundle') &&
    !window.localStorage.getItem('WAToken1') &&
    !window.localStorage.getItem('WAToken2')
  ) {
    return true;
  }
  return false;
}


/***/ }),

/***/ "./functions/help/return-to-chat.js":
/*!******************************************!*\
  !*** ./functions/help/return-to-chat.js ***!
  \******************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   returnChat: () => (/* binding */ returnChat)
/* harmony export */ });
/**
 * Function to return to chat or create a new chat
 * @param {*} chatId - Chat ID
 * @param {*} returnChat - Return Chat
 * @param {*} Send - Seen to message
 * @returns
 */
const returnChat = async (chatId, returnChat = true, Send = true) => {
  const checkType = API.sendCheckType(chatId);
  if (!!checkType && checkType.status === 404) {
    return checkType;
  }

  let chat = await window.API.getChat(chatId);
  if (!chat) {
    var idUser = new Store.UserConstructor(chatId, {
      intentionallyUsePrivateConstructor: true,
    });
    const chatWid = new Store.WidFactory.createWid(chatId);
    await Store.Chat.add(
      {
        createdLocally: true,
        id: chatWid,
      },
      {
        merge: true,
      }
    );
    chat = await Store.Chat.find(idUser);
  }

  if (chat === undefined) {
    const chatWid = new Store.WidFactory.createWid(chatId);
    await Store.Chat.add(
      {
        createdLocally: true,
        id: chatWid,
      },
      {
        merge: true,
      }
    );
    const storeChat = await Store.Chat.find(chatId);
    if (storeChat) {
      chat =
        storeChat && storeChat.id && storeChat.id._serialized
          ? await window.API.getChat(storeChat.id._serialized)
          : undefined;
    }
  }

  if (!chat) {
    return API.scope(chatId, true, 404);
  }

  if (Send) {
    await window.Store.ReadSeen.sendSeen(chat, false);
  }

  if (returnChat) {
    return chat;
  }

  return API.scope(chatId, false, 200);
};


/***/ }),

/***/ "./functions/help/scope.js":
/*!*********************************!*\
  !*** ./functions/help/scope.js ***!
  \*********************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   scope: () => (/* binding */ scope)
/* harmony export */ });
async function scope(
  id,
  erro,
  status,
  text = null,
  type = null,
  body = null
) {
  let e = {
    to: id,
    error: erro,
    text: text,
    status: status,
    type: type,
    body: body,
  };
  return e;
}


/***/ }),

/***/ "./functions/help/send-check-type.js":
/*!*******************************************!*\
  !*** ./functions/help/send-check-type.js ***!
  \*******************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   sendCheckType: () => (/* binding */ sendCheckType)
/* harmony export */ });
function sendCheckType(chatId = undefined) {
  if (!chatId) {
    return API.scope(chatId, true, 404, 'It is necessary to pass a number!');
  }

  if (typeof chatId === 'string') {
    const contact = '@c.us';
    const broadcast = '@broadcast';
    const grup = '@g.us';

    if (
      contact !== chatId.substr(-contact.length, contact.length) &&
      broadcast !== chatId.substr(-broadcast.length, broadcast.length) &&
      grup !== chatId.substr(-grup.length, grup.length)
    ) {
      return API.scope(
        chatId,
        true,
        404,
        'The chat number must contain the parameters @c.us, @broadcast or @g.us. At the end of the number!'
      );
    }

    if (
      contact === chatId.substr(-contact.length, contact.length) &&
      ((chatId.match(/(@c.us)/g) && chatId.match(/(@c.us)/g).length > 1) ||
        !chatId.match(/^(\d+(\d)*@c.us)$/g))
    ) {
      return API.scope(
        chatId,
        true,
        404,
        'incorrect parameters! Use as an example: 000000000000@c.us'
      );
    }

    if (
      broadcast === chatId.substr(-broadcast.length, broadcast.length) &&
      (chatId.match(/(@broadcast)/g).length > 1 ||
        (!chatId.match(/^(\d+(\d)*@broadcast)$/g) &&
          !chatId.match(/^(status@broadcast)$/g)))
    ) {
      return API.scope(
        chatId,
        true,
        404,
        'incorrect parameters! Use as an example: 0000000000@broadcast'
      );
    }

    if (
      grup === chatId.substr(-grup.length, grup.length) &&
      ((chatId.match(/(@g.us)/g) && chatId.match(/(@g.us)/g).length > 1) ||
        !chatId.match(/^(\d+(-)+(\d)|\d+(\d))*@g.us$/g))
    ) {
      return API.scope(
        chatId,
        true,
        404,
        'incorrect parameters! Use as an example: 00000000-000000@g.us or 00000000000000@g.us'
      );
    }
  }
}


/***/ }),

/***/ "./functions/help/send-exist.js":
/*!**************************************!*\
  !*** ./functions/help/send-exist.js ***!
  \**************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   sendExist: () => (/* binding */ sendExist)
/* harmony export */ });
/**
 * Function to check if the number exists and return the chat
 * @param {*} chatId
 * @param {*} returnChat
 * @param {*} Send
 * @returns
 */
const sendExist = async (chatId, returnChat = true, Send = true) => {
  const checkContact = API.getContact(chatId);
  if (checkContact) {
    return await API.returnChat(chatId);
  }

  const checkType = await API.sendCheckType(chatId);
  if (!!checkType && checkType.status === 404) {
    return checkType;
  }

  let ck = await window.API.checkNumberStatus(chatId, false);
  if (
    (ck.status === 404 &&
      !chatId.includes('@g.us') &&
      !chatId.includes('@broadcast')) ||
    (ck &&
      ck.text &&
      typeof ck.text.includes === 'function' &&
      ck.text.includes('XmppParsingFailure'))
  ) {
    return API.scope(chatId, true, ck.status, 'The number does not exist');
  }

  const chatWid = new window.Store.WidFactory.createWid(chatId);

  let chat =
    ck && ck.id && ck.id._serialized
      ? await window.API.getChat(ck.id._serialized)
      : undefined;

  if (ck.numberExists && chat === undefined) {
    var idUser = new window.Store.UserConstructor(chatId, {
      intentionallyUsePrivateConstructor: true,
    });
    chat = await window.Store.Chat.find(idUser);
  }

  if (!chat) {
    const storeChat = await window.Store.Chat.find(chatWid);
    if (storeChat) {
      chat =
        storeChat && storeChat.id && storeChat.id._serialized
          ? await window.API.getChat(storeChat.id._serialized)
          : undefined;
    }
  }

  if (!ck.numberExists && !chat.t && chat.isUser) {
    return window.API.scope(
      chatId,
      true,
      ck.status,
      'The number does not exist'
    );
  }

  if (!ck.numberExists && !chat.t && chat.isGroup) {
    return window.API.scope(
      chatId,
      true,
      ck.status,
      'The group number does not exist on your chat list, or it does not exist at all!'
    );
  }

  if (!chat) {
    return window.API.scope(chatId, true, 404);
  }

  if (Send) {
    await window.Store.ReadSeen.sendSeen(chat, false);
  }

  if (returnChat) {
    return chat;
  }
  return window.API.scope(chatId, false, 200);
};


/***/ }),

/***/ "./functions/index.js":
/*!****************************!*\
  !*** ./functions/index.js ***!
  \****************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   addParticipant: () => (/* reexport safe */ _add_participant__WEBPACK_IMPORTED_MODULE_2__.addParticipant),
/* harmony export */   baseSendMessage: () => (/* reexport safe */ _send_message__WEBPACK_IMPORTED_MODULE_0__.baseSendMessage),
/* harmony export */   createGroup: () => (/* reexport safe */ _create_group__WEBPACK_IMPORTED_MODULE_1__.createGroup),
/* harmony export */   getAllChats: () => (/* reexport safe */ _get_all_chats__WEBPACK_IMPORTED_MODULE_7__.getAllChats),
/* harmony export */   getAllContacts: () => (/* reexport safe */ _get_all_contacts__WEBPACK_IMPORTED_MODULE_8__.getAllContacts),
/* harmony export */   getContact: () => (/* reexport safe */ _get_contact__WEBPACK_IMPORTED_MODULE_6__.getContact),
/* harmony export */   getHost: () => (/* reexport safe */ _get_host__WEBPACK_IMPORTED_MODULE_5__.getHost),
/* harmony export */   getWAVersion: () => (/* reexport safe */ _get_wa_version__WEBPACK_IMPORTED_MODULE_9__.getWAVersion),
/* harmony export */   sendMessage: () => (/* reexport safe */ _send_message__WEBPACK_IMPORTED_MODULE_0__.sendMessage),
/* harmony export */   setGroupDescription: () => (/* reexport safe */ _set_group_description__WEBPACK_IMPORTED_MODULE_3__.setGroupDescription),
/* harmony export */   setGroupImage: () => (/* reexport safe */ _set_group_image__WEBPACK_IMPORTED_MODULE_4__.setGroupImage)
/* harmony export */ });
/* harmony import */ var _send_message__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./send-message */ "./functions/send-message.js");
/* harmony import */ var _create_group__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./create-group */ "./functions/create-group.js");
/* harmony import */ var _add_participant__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./add-participant */ "./functions/add-participant.js");
/* harmony import */ var _set_group_description__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./set-group-description */ "./functions/set-group-description.js");
/* harmony import */ var _set_group_image__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./set-group-image */ "./functions/set-group-image.js");
/* harmony import */ var _get_host__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./get-host */ "./functions/get-host.js");
/* harmony import */ var _get_contact__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./get-contact */ "./functions/get-contact.js");
/* harmony import */ var _get_all_chats__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./get-all-chats */ "./functions/get-all-chats.js");
/* harmony import */ var _get_all_contacts__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./get-all-contacts */ "./functions/get-all-contacts.js");
/* harmony import */ var _get_wa_version__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./get-wa-version */ "./functions/get-wa-version.js");
// Send Functions


// Create Functions



// Set Functions



// Get Functions







/***/ }),

/***/ "./functions/send-message.js":
/*!***********************************!*\
  !*** ./functions/send-message.js ***!
  \***********************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   baseSendMessage: () => (/* binding */ baseSendMessage),
/* harmony export */   sendMessage: () => (/* binding */ sendMessage)
/* harmony export */ });
/**
 * send message in options mode
 * @param {string} to contact number
 * @param {string} body message body
 * @param {object} options shipping options
 */
async function sendMessage(to, body, options = {}) {
  const types = [
    'sendText',
    'sendAudioBase64',
    'sendImageFromBase64',
    'sendAudio',
    'sendFile',
    'sendImage',
  ];

  let typesObj;
  types.reduce(
    (a, v) =>
      (typesObj = {
        ...a,
        [v]: v,
      }),
    {}
  );

  if (!body) {
    return API.scope(undefined, true, null, `parameters are missing`);
  }

  if (!options.type || (options.type && !types.includes(options.type))) {
    return API.scope(
      undefined,
      true,
      null,
      `pass the message type, examples: ${types.join(', ')}`
    );
  }

  const chat = await API.sendExist(to);
  const merge = {};

  if (chat && chat.status != 404 && chat.id) {
    const newMsgId = await window.API.getNewMessageId(chat.id._serialized);
    const fromwWid = await window.Store.MaybeMeUser.getMaybeMeUser();

    if (options.type === typesObj.sendText) {
      merge.type = 'chat';
    }

    if (
      options.type === typesObj.sendAudioBase64 ||
      options.type === typesObj.sendAudio ||
      options.type === typesObj.sendFile ||
      options.type === typesObj.sendImage ||
      options.type === typesObj.sendImageFromBase64
    ) {
      let result = await Store.Chat.find(chat.id);
      const mediaBlob = API.base64ToFile(body);
      const mc = await API.processFiles(result, mediaBlob);
      if (typeof mc === 'object' && mc._models && mc._models[0]) {
        const media = mc._models[0];
        let enc, type;

        if (
          options.type === typesObj.sendFile ||
          options.type === typesObj.sendImage ||
          options.type === typesObj.sendImageFromBase64
        ) {
          type = media.type;
          merge.caption = options?.caption;
          merge.filename = options?.filename;
          enc = await API.encryptAndUploadFile(type, mediaBlob);
        } else {
          type = 'ptt';
          enc = await API.encryptAndUploadFile(type, mediaBlob);
        }

        if (enc === false) {
          return API.scope(chat.id, true, 404, 'Error to encryptAndUploadFile');
        }

        merge.type = type;
        merge.duration = media?.__x_mediaPrep?._mediaData?.duration;
        merge.mimetype = media.mimetype;
        merge.size = media.filesize;
        merge.deprecatedMms3Url = enc.url;
        merge.directPath = enc.directPath;
        merge.encFilehash = enc.encFilehash;
        merge.filehash = enc.filehash;
        merge.mediaKeyTimestamp = enc.mediaKeyTimestamp;
        merge.ephemeralStartTimestamp = enc.mediaKeyTimestamp;
        merge.mediaKey = enc.mediaKey;
        body = undefined;
      }
    }

    if (!Object.keys(merge).length) {
      return API.scope(undefined, true, null, 'Error sending message');
    }

    const message = window.API.baseSendMessage(
      {
        to,
        body,
        newMsgId,
        fromwWid,
        chat,
      },
      merge
    );

    try {
      const result = (
        await Promise.all(window.Store.addAndSendMsgToChat(chat, message))
      )[1];
      if (
        result === 'success' ||
        result === 'OK' ||
        result?.messageSendResult === 'OK'
      ) {
        return API.scope(newMsgId, false, result, null, options.type, body);
      }
      throw result;
    } catch (result) {
      return API.scope(newMsgId, true, result, null, options.type, body);
    }
  } else {
    if (!chat.erro) {
      chat.erro = true;
    }

    return chat;
  }
}

/**
 * Function to base send message
 * @param {*} param - Object with information to send the message
 * @param {*} merge - Object with information to merge with the message
 * @returns - Object with message information
 */
function baseSendMessage(param, merge) {
  const message = {
    id: param.newMsgId,
    ack: 0,
    body: param?.body,
    from: param.fromwWid,
    to: param.chat.id,
    local: !0,
    self: 'out',
    t: parseInt(new Date().getTime() / 1000),
    isNewMsg: !0,
    ...merge,
  };
  return message;
}


/***/ }),

/***/ "./functions/set-group-description.js":
/*!********************************************!*\
  !*** ./functions/set-group-description.js ***!
  \********************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   setGroupDescription: () => (/* binding */ setGroupDescription)
/* harmony export */ });
/**
 * Parameters to change group description
 * @param {string} groupId group number
 * @param {string} description group description
 */
async function setGroupDescription(groupId, description) {
  const nameFunc = new Error().stack
    .match(/at (.*?) /)[1]
    .replace('Object.', '');
  if (typeof description != 'string' || description.length === 0) {
    return API.scope(groupId, true, 400, 'It is necessary to write a text!');
  }
  const chat = await API.sendExist(groupId);
  if (chat && chat.status != 404) {
    try {
      await window.Store.GroupDesc.setGroupDesc(chat, description);
      return API.scope(
        groupId,
        false,
        200,
        `Description successfully changed`,
        nameFunc,
        description
      );
    } catch {
      return API.scope(
        groupId,
        true,
        400,
        `Unable to change description`,
        nameFunc,
        description
      );
    }
  } else {
    return chat;
  }
}


/***/ }),

/***/ "./functions/set-group-image.js":
/*!**************************************!*\
  !*** ./functions/set-group-image.js ***!
  \**************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   setGroupImage: () => (/* binding */ setGroupImage)
/* harmony export */ });
/**
 * Parameters to change group image
 * @param {object} path of image
 * @param {string} groupId group number
 */
async function setGroupImage(obj, groupId) {
  const nameFunc = new Error().stack
    .match(/at (.*?) /)[1]
    .replace('Object.', '');
  if (typeof groupId !== 'string' || groupId.length === 0) {
    return API.scope(groupId, true, 400, 'You must pass the group groupId!');
  }
  const chat = await API.sendExist(groupId);
  if (chat && chat.status != 404) {
    groupId = new Store.WidFactory.createWid(groupId);
    let base64 = 'data:image/jpeg;base64,';
    try {
      const sendPinture = await Store.Profile.sendSetPicture(
        groupId,
        base64 + obj.b,
        base64 + obj.a
      );
      return API.scope(
        groupId,
        false,
        200,
        `Image changed successfully`,
        nameFunc,
        sendPinture
      );
    } catch {
      return API.scope(
        groupId,
        true,
        400,
        `Unable to change image`,
        nameFunc,
        null
      );
    }
  } else {
    return chat;
  }
}


/***/ }),

/***/ "./help/array-buffer-to-base64.js":
/*!****************************************!*\
  !*** ./help/array-buffer-to-base64.js ***!
  \****************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   arrayBufferToBase64: () => (/* binding */ arrayBufferToBase64)
/* harmony export */ });
function arrayBufferToBase64(arrayBuffer) {
  var base64 = '';
  var encodings =
    'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';

  var bytes = new Uint8Array(arrayBuffer);
  var byteLength = bytes.byteLength;
  var byteRemainder = byteLength % 3;
  var mainLength = byteLength - byteRemainder;

  var a, b, c, d;
  var chunk;

  // Main loop deals with bytes in chunks of 3
  for (var i = 0; i < mainLength; i = i + 3) {
    // Combine the three bytes into a single integer
    chunk = (bytes[i] << 16) | (bytes[i + 1] << 8) | bytes[i + 2];

    // Use bitmasks to extract 6-bit segments from the triplet
    a = (chunk & 16515072) >> 18; // 16515072 = (2^6 - 1) << 18
    b = (chunk & 258048) >> 12; // 258048   = (2^6 - 1) << 12
    c = (chunk & 4032) >> 6; // 4032     = (2^6 - 1) << 6
    d = chunk & 63; // 63       = 2^6 - 1

    // Convert the raw binary segments to the appropriate ASCII encoding
    base64 += encodings[a] + encodings[b] + encodings[c] + encodings[d];
  }

  // Deal with the remaining bytes and padding
  if (byteRemainder == 1) {
    chunk = bytes[mainLength];

    a = (chunk & 252) >> 2; // 252 = (2^6 - 1) << 2

    // Set the 4 least significant bits to zero
    b = (chunk & 3) << 4; // 3   = 2^2 - 1

    base64 += encodings[a] + encodings[b] + '==';
  } else if (byteRemainder == 2) {
    chunk = (bytes[mainLength] << 8) | bytes[mainLength + 1];

    a = (chunk & 64512) >> 10; // 64512 = (2^6 - 1) << 10
    b = (chunk & 1008) >> 4; // 1008  = (2^6 - 1) << 4

    // Set the 2 least significant bits to zero
    c = (chunk & 15) << 2; // 15    = 2^4 - 1

    base64 += encodings[a] + encodings[b] + encodings[c] + '=';
  }
  return base64;
}


/***/ }),

/***/ "./help/base64ToFile.js":
/*!******************************!*\
  !*** ./help/base64ToFile.js ***!
  \******************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   base64ToFile: () => (/* binding */ base64ToFile)
/* harmony export */ });
function base64ToFile(base64, filename) {
  try {
    const arr = base64.split(',');
    let mime = arr[0].match(/(?:data:)?(.*?)(?:;base64)?$/i)[1];
    mime = mime.split(/\s+;\s+/).join('; '); // Fix spaces, like "audio/ogg; codecs=opus"

    const bstr = window.Base64 ? window.Base64.atob(arr[1]) : atob(arr[1]);
    let n = bstr.length;
    const u8arr = new Uint8Array(n);

    while (n--) {
      u8arr[n] = bstr.charCodeAt(n);
    }

    return new File([u8arr], filename, {
      type: mime,
    });
  } catch {
    return false;
  }
}


/***/ }),

/***/ "./help/encrypt-and-upload-file.js":
/*!*****************************************!*\
  !*** ./help/encrypt-and-upload-file.js ***!
  \*****************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   encryptAndUploadFile: () => (/* binding */ encryptAndUploadFile)
/* harmony export */ });
async function encryptAndUploadFile(type, blob) {
  try {
    const filehash = await API.getFileHash(blob);
    const mediaKey = API.generateMediaKey(32);
    const controller = new AbortController();
    const signal = controller.signal;
    const encrypted = await window.Store.UploadUtils.encryptAndUpload({
      blob,
      type,
      signal,
      mediaKey,
    });
    return {
      ...encrypted,
      clientUrl: encrypted.url,
      filehash,
      id: filehash,
      uploadhash: encrypted.encFilehash,
      mediaBlob: blob,
    };
  } catch {
    return false;
  }
}


/***/ }),

/***/ "./help/filter-module.js":
/*!*******************************!*\
  !*** ./help/filter-module.js ***!
  \*******************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   filterModule: () => (/* binding */ filterModule)
/* harmony export */ });
async function filterModule(filterObjects, modules) {
  let found = 0;
  for (let i in modules) {
    if (typeof modules[i] === 'object' && modules[i] !== null) {
      filterObjects.forEach((needObj) => {
        if (!needObj.when | needObj.yesModule) return;

        const checkObj = needObj.when(modules[i]);
        if (checkObj !== null) {
          found++;
          needObj.yesModule = checkObj;
        }
      });
      if (found == filterObjects.length) {
        break;
      }
    }
  }
  return filterObjects;
}


/***/ }),

/***/ "./help/filter-object.js":
/*!*******************************!*\
  !*** ./help/filter-object.js ***!
  \*******************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   filterObjects: () => (/* binding */ filterObjects)
/* harmony export */ });
const filterObjects = [
  {
    type: 'Module',
    when: (module) =>
      module.default && module.default.Chat && module.default.Msg
        ? module.default
        : null,
  },
  {
    type: 'Conn',
    when: (module) => (module.Conn ? module.Conn : null),
  },
  {
    type: 'ChatCollection',
    when: (module) => (module.ChatCollection ? module.ChatCollection : null),
  },
  {
    type: 'addAndSendMsgToChat',
    when: (module) =>
      module.addAndSendMsgToChat ? module.addAndSendMsgToChat : null,
  },
  {
    type: 'UserConstructor',
    when: (module) =>
      module.default &&
      module.default.prototype &&
      module.default.prototype.isServer &&
      module.default.prototype.isUser
        ? module.default
        : null,
  },
  {
    type: 'WidFactory',
    when: (module) => (module.createWid ? module : null),
  },
  {
    type: 'MsgKey',
    when: (module) =>
      module.default &&
      module.default.toString &&
      typeof module.default.toString === 'function' &&
      module.default.toString().includes('MsgKey error: obj is null/undefined')
        ? module.default
        : null,
  },
  {
    type: 'State',
    when: (module) => (module.Socket ? module : null),
  },
  {
    type: 'addAndSendMsgToChat',
    when: (module) =>
      module.addAndSendMsgToChat ? module.addAndSendMsgToChat : null,
  },
  {
    type: 'checkNumber',
    when: (module) => (module.queryExist ? module : null),
  },
  {
    type: 'ReadSeen',
    when: (module) => (module.sendSeen ? module : null),
  },
  {
    type: 'Stream',
    when: (module) =>
      module.Stream && module.StreamInfo ? module.Stream : null,
  },
  {
    type: 'MediaCollection',
    when: (module) =>
      module.default &&
      module.default.prototype &&
      (module.default.prototype.processFiles !== undefined ||
        module.default.prototype.processAttachments !== undefined)
        ? module.default
        : null,
  },
  {
    type: 'UploadUtils',
    when: (module) =>
      module.default && module.default.encryptAndUpload ? module.default : null,
  },
  {
    type: 'blob',
    when: (module) =>
      module.default && module.default.createFromData ? module : null,
  },
  {
    type: 'createGroup',
    when: (module) =>
      module.createGroup && module.sendForNeededAddRequest
        ? module.createGroup
        : null,
  },
  {
    type: 'GroupDesc',
    when: (module) => (module.setGroupDesc ? module : null),
  },
  {
    type: 'CheckWid',
    when: (module) => (module.validateWid ? module : null),
  },
  {
    type: 'Participants',
    when: (module) =>
      module.addParticipants && module.promoteCommunityParticipants
        ? module
        : null,
  },
  {
    type: 'MyStatus',
    when: (module) => (module.getStatus && module.setMyStatus ? module : null),
  },
  {
    type: 'Profile',
    when: (module) =>
      module.sendSetPicture && module.requestDeletePicture ? module : null,
  },
  {
    type: 'Contacts',
    when: (module) => (module.ContactCollection ? module : null),
  },
  {
    type: 'MaybeMeUser',
    when: (module) => (module.getMaybeMeUser ? module : null),
  },
];


/***/ }),

/***/ "./help/generate-media-key.js":
/*!************************************!*\
  !*** ./help/generate-media-key.js ***!
  \************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   generateMediaKey: () => (/* binding */ generateMediaKey)
/* harmony export */ });
function generateMediaKey(length) {
  let result = '';
  let characters =
    'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
  for (let i = 0; i < length; i++) {
    result += characters.charAt(Math.floor(Math.random() * characters.length));
  }
  return result;
}


/***/ }),

/***/ "./help/get-file-hash.js":
/*!*******************************!*\
  !*** ./help/get-file-hash.js ***!
  \*******************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   getFileHash: () => (/* binding */ getFileHash)
/* harmony export */ });
/* harmony import */ var _jssha__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../jssha */ "./jssha/index.js");
/* harmony import */ var _jssha__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_jssha__WEBPACK_IMPORTED_MODULE_0__);

async function getFileHash(data) {
  let buffer = await data.arrayBuffer();
  var sha = new _jssha__WEBPACK_IMPORTED_MODULE_0__('SHA-256', 'ARRAYBUFFER');
  sha.update(buffer);
  return sha.getHash('B64');
}


/***/ }),

/***/ "./help/get-module-list.js":
/*!*********************************!*\
  !*** ./help/get-module-list.js ***!
  \*********************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   getModuleList: () => (/* binding */ getModuleList)
/* harmony export */ });
const getModuleList = async () => {
  return new Promise((resolve) => {
    let modules = {};
    if (!window?.__debug?.modulesMap) {
      try {
        const debug = /*require.resolve*/(Object(function webpackMissingModule() { var e = new Error("Cannot find module '__debug'"); e.code = 'MODULE_NOT_FOUND'; throw e; }()));
        if (debug) {
          window['__debug'] = __webpack_require__(Object(function webpackMissingModule() { var e = new Error("Cannot find module '__debug'"); e.code = 'MODULE_NOT_FOUND'; throw e; }()));
        } else {
          throw new Error('__debug not found');
        }
      } catch {
        return getModuleList();
      }
    }

    Object.keys(window.__debug.modulesMap)
      .filter((e) => e.includes('WA'))
      .forEach(function (mod) {
        let module = window.__debug.modulesMap[mod];
        if (module) {
          modules[mod] = {
            default: module.defaultExport,
            factory: module.factory,
          };
          if (Object.keys(modules[mod].default).length === 0) {
            try {
              self.ErrorGuard.skipGuardGlobal(true);
              Object.assign(modules[mod], self.importNamespace(mod));
            } catch {}
          }
        }
      });
    resolve(modules);
  });
};


/***/ }),

/***/ "./help/index.js":
/*!***********************!*\
  !*** ./help/index.js ***!
  \***********************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   arrayBufferToBase64: () => (/* reexport safe */ _array_buffer_to_base64__WEBPACK_IMPORTED_MODULE_5__.arrayBufferToBase64),
/* harmony export */   base64ToFile: () => (/* reexport safe */ _base64ToFile__WEBPACK_IMPORTED_MODULE_3__.base64ToFile),
/* harmony export */   encryptAndUploadFile: () => (/* reexport safe */ _encrypt_and_upload_file__WEBPACK_IMPORTED_MODULE_7__.encryptAndUploadFile),
/* harmony export */   filterModule: () => (/* reexport safe */ _filter_module__WEBPACK_IMPORTED_MODULE_8__.filterModule),
/* harmony export */   filterObjects: () => (/* reexport safe */ _filter_object__WEBPACK_IMPORTED_MODULE_10__.filterObjects),
/* harmony export */   generateMediaKey: () => (/* reexport safe */ _generate_media_key__WEBPACK_IMPORTED_MODULE_4__.generateMediaKey),
/* harmony export */   getFileHash: () => (/* reexport safe */ _get_file_hash__WEBPACK_IMPORTED_MODULE_6__.getFileHash),
/* harmony export */   getModuleList: () => (/* reexport safe */ _get_module_list__WEBPACK_IMPORTED_MODULE_9__.getModuleList),
/* harmony export */   injectParasite: () => (/* reexport safe */ _inject_paresite__WEBPACK_IMPORTED_MODULE_1__.injectParasite),
/* harmony export */   processFiles: () => (/* reexport safe */ _process_files__WEBPACK_IMPORTED_MODULE_2__.processFiles),
/* harmony export */   sleep: () => (/* reexport safe */ _sleep__WEBPACK_IMPORTED_MODULE_0__.sleep)
/* harmony export */ });
/* harmony import */ var _sleep__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./sleep */ "./help/sleep.js");
/* harmony import */ var _inject_paresite__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./inject-paresite */ "./help/inject-paresite.js");
/* harmony import */ var _process_files__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./process-files */ "./help/process-files.js");
/* harmony import */ var _base64ToFile__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./base64ToFile */ "./help/base64ToFile.js");
/* harmony import */ var _generate_media_key__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./generate-media-key */ "./help/generate-media-key.js");
/* harmony import */ var _array_buffer_to_base64__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./array-buffer-to-base64 */ "./help/array-buffer-to-base64.js");
/* harmony import */ var _get_file_hash__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./get-file-hash */ "./help/get-file-hash.js");
/* harmony import */ var _encrypt_and_upload_file__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./encrypt-and-upload-file */ "./help/encrypt-and-upload-file.js");
/* harmony import */ var _filter_module__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./filter-module */ "./help/filter-module.js");
/* harmony import */ var _get_module_list__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./get-module-list */ "./help/get-module-list.js");
/* harmony import */ var _filter_object__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./filter-object */ "./help/filter-object.js");














/***/ }),

/***/ "./help/inject-paresite.js":
/*!*********************************!*\
  !*** ./help/inject-paresite.js ***!
  \*********************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   injectParasite: () => (/* binding */ injectParasite)
/* harmony export */ });
/* harmony import */ var _index__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./index */ "./help/index.js");


const injectParasite = async () => {
  const modules = await (0,_index__WEBPACK_IMPORTED_MODULE_0__.getModuleList)();
  const filterMod = await (0,_index__WEBPACK_IMPORTED_MODULE_0__.filterModule)(_index__WEBPACK_IMPORTED_MODULE_0__.filterObjects, modules);
  filterMod.forEach((needObj) => {
    if (needObj.yesModule) {
      if (needObj.type !== 'Module') {
        if (!window.Store[needObj.type]) {
          window.Store[needObj.type] = needObj.yesModule;
        }
      }
    }
  });

  const module = filterMod.filter((e) => e.type === 'Module')[0].yesModule;
  Object.keys(module).forEach((key) => {
    if (!Store[key]) {
      Store[key] = module[key];
    }
  });
};


/***/ }),

/***/ "./help/process-files.js":
/*!*******************************!*\
  !*** ./help/process-files.js ***!
  \*******************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   processFiles: () => (/* binding */ processFiles)
/* harmony export */ });
async function processFiles(chat, blobs) {
  if (!Array.isArray(blobs)) {
    blobs = [blobs];
  }

  const mediaCollection = new Store.MediaCollection({
    chatParticipantCount: chat.getParticipantCount(),
  });

  await mediaCollection.processAttachments(
    blobs.map((blob) => {
      return {
        file: blob,
        filename: blob.name,
        mimetype: blob.type,
      };
    }),
    true,
    chat
  );

  return mediaCollection;
}


/***/ }),

/***/ "./help/sleep.js":
/*!***********************!*\
  !*** ./help/sleep.js ***!
  \***********************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   sleep: () => (/* binding */ sleep)
/* harmony export */ });
function sleep(time) {
  try {
    return new Promise((resolve) => setTimeout(resolve, time));
  } catch (e) {}
}


/***/ }),

/***/ "./init-parasite.js":
/*!**************************!*\
  !*** ./init-parasite.js ***!
  \**************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   initParasite: () => (/* binding */ initParasite)
/* harmony export */ });
/* harmony import */ var _help_inject_paresite__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./help/inject-paresite */ "./help/inject-paresite.js");

/**
 * Wait for modules
 */
const waitForObjects = async () => {
  return new Promise((resolve) => {
    let timeoutId;
    const checkObjects = () => {
      const canvasQrcode = document.querySelectorAll('canvas').length;
      const chat = document.querySelectorAll('#app .two').length;
      const FB = window['__d'];

      if ((canvasQrcode && FB) || (chat && FB)) {
        clearTimeout(timeoutId);
        return resolve({ fb: true });
      } else {
        timeoutId = setTimeout(checkObjects, 200);
      }
    };
    checkObjects();
  });
};

/**
 * Inject parasite
 */
const initParasite = async () => {
  window.Store = {};
  const store =
    window.Store && Object.keys(window.Store).length === 0 ? false : true;
  if (!store) {
    const { fb } = await waitForObjects();
    if (fb) {
      (0,_help_inject_paresite__WEBPACK_IMPORTED_MODULE_0__.injectParasite)();
    }
  }
};


/***/ }),

/***/ "./jssha/index.js":
/*!************************!*\
  !*** ./jssha/index.js ***!
  \************************/
/***/ (function(module, exports, __webpack_require__) {

var __WEBPACK_AMD_DEFINE_RESULT__;
(function (aa) {
  function C(e, b, a) {
    var k = 0,
      h = [],
      l = 0,
      g,
      m,
      c,
      f,
      n,
      q,
      u,
      r,
      I = !1,
      v = [],
      x = [],
      t,
      y = !1,
      z = !1,
      w = -1;
    a = a || {};
    g = a.encoding || 'UTF8';
    t = a.numRounds || 1;
    if (t !== parseInt(t, 10) || 1 > t)
      throw Error('numRounds must a integer >= 1');
    if ('SHA-1' === e)
      (n = 512),
        (q = K),
        (u = ba),
        (f = 160),
        (r = function (b) {
          return b.slice();
        });
    else if (0 === e.lastIndexOf('SHA-', 0))
      if (
        ((q = function (b, k) {
          return L(b, k, e);
        }),
        (u = function (b, k, h, a) {
          var d, f;
          if ('SHA-224' === e || 'SHA-256' === e)
            (d = (((k + 65) >>> 9) << 4) + 15), (f = 16);
          else if ('SHA-384' === e || 'SHA-512' === e)
            (d = (((k + 129) >>> 10) << 5) + 31), (f = 32);
          else throw Error('Unexpected error in SHA-2 implementation');
          for (; b.length <= d; ) b.push(0);
          b[k >>> 5] |= 128 << (24 - (k % 32));
          k = k + h;
          b[d] = k & 4294967295;
          b[d - 1] = (k / 4294967296) | 0;
          h = b.length;
          for (k = 0; k < h; k += f) a = L(b.slice(k, k + f), a, e);
          if ('SHA-224' === e) b = [a[0], a[1], a[2], a[3], a[4], a[5], a[6]];
          else if ('SHA-256' === e) b = a;
          else if ('SHA-384' === e)
            b = [
              a[0].a,
              a[0].b,
              a[1].a,
              a[1].b,
              a[2].a,
              a[2].b,
              a[3].a,
              a[3].b,
              a[4].a,
              a[4].b,
              a[5].a,
              a[5].b,
            ];
          else if ('SHA-512' === e)
            b = [
              a[0].a,
              a[0].b,
              a[1].a,
              a[1].b,
              a[2].a,
              a[2].b,
              a[3].a,
              a[3].b,
              a[4].a,
              a[4].b,
              a[5].a,
              a[5].b,
              a[6].a,
              a[6].b,
              a[7].a,
              a[7].b,
            ];
          else throw Error('Unexpected error in SHA-2 implementation');
          return b;
        }),
        (r = function (b) {
          return b.slice();
        }),
        'SHA-224' === e)
      )
        (n = 512), (f = 224);
      else if ('SHA-256' === e) (n = 512), (f = 256);
      else if ('SHA-384' === e) (n = 1024), (f = 384);
      else if ('SHA-512' === e) (n = 1024), (f = 512);
      else throw Error('Chosen SHA variant is not supported');
    else if (
      0 === e.lastIndexOf('SHA3-', 0) ||
      0 === e.lastIndexOf('SHAKE', 0)
    ) {
      var F = 6;
      q = D;
      r = function (b) {
        var e = [],
          a;
        for (a = 0; 5 > a; a += 1) e[a] = b[a].slice();
        return e;
      };
      w = 1;
      if ('SHA3-224' === e) (n = 1152), (f = 224);
      else if ('SHA3-256' === e) (n = 1088), (f = 256);
      else if ('SHA3-384' === e) (n = 832), (f = 384);
      else if ('SHA3-512' === e) (n = 576), (f = 512);
      else if ('SHAKE128' === e) (n = 1344), (f = -1), (F = 31), (z = !0);
      else if ('SHAKE256' === e) (n = 1088), (f = -1), (F = 31), (z = !0);
      else throw Error('Chosen SHA variant is not supported');
      u = function (b, e, a, k, h) {
        a = n;
        var d = F,
          f,
          g = [],
          l = a >>> 5,
          m = 0,
          c = e >>> 5;
        for (f = 0; f < c && e >= a; f += l)
          (k = D(b.slice(f, f + l), k)), (e -= a);
        b = b.slice(f);
        for (e %= a; b.length < l; ) b.push(0);
        f = e >>> 3;
        b[f >> 2] ^= d << ((f % 4) * 8);
        b[l - 1] ^= 2147483648;
        for (k = D(b, k); 32 * g.length < h; ) {
          b = k[m % 5][(m / 5) | 0];
          g.push(b.b);
          if (32 * g.length >= h) break;
          g.push(b.a);
          m += 1;
          0 === (64 * m) % a && D(null, k);
        }
        return g;
      };
    } else throw Error('Chosen SHA variant is not supported');
    c = M(b, g, w);
    m = A(e);
    this.setHMACKey = function (b, a, h) {
      var d;
      if (!0 === I) throw Error('HMAC key already set');
      if (!0 === y) throw Error('Cannot set HMAC key after calling update');
      if (!0 === z) throw Error('SHAKE is not supported for HMAC');
      g = (h || {}).encoding || 'UTF8';
      a = M(a, g, w)(b);
      b = a.binLen;
      a = a.value;
      d = n >>> 3;
      h = d / 4 - 1;
      if (d < b / 8) {
        for (a = u(a, b, 0, A(e), f); a.length <= h; ) a.push(0);
        a[h] &= 4294967040;
      } else if (d > b / 8) {
        for (; a.length <= h; ) a.push(0);
        a[h] &= 4294967040;
      }
      for (b = 0; b <= h; b += 1)
        (v[b] = a[b] ^ 909522486), (x[b] = a[b] ^ 1549556828);
      m = q(v, m);
      k = n;
      I = !0;
    };
    this.update = function (b) {
      var a,
        e,
        d,
        f = 0,
        g = n >>> 5;
      a = c(b, h, l);
      b = a.binLen;
      e = a.value;
      a = b >>> 5;
      for (d = 0; d < a; d += g)
        f + n <= b && ((m = q(e.slice(d, d + g), m)), (f += n));
      k += f;
      h = e.slice(f >>> 5);
      l = b % n;
      y = !0;
    };
    this.getHash = function (b, a) {
      var d, g, c, n;
      if (!0 === I) throw Error('Cannot call getHash after setting HMAC key');
      c = N(a);
      if (!0 === z) {
        if (-1 === c.shakeLen)
          throw Error('shakeLen must be specified in options');
        f = c.shakeLen;
      }
      switch (b) {
        case 'HEX':
          d = function (b) {
            return O(b, f, w, c);
          };
          break;
        case 'B64':
          d = function (b) {
            return P(b, f, w, c);
          };
          break;
        case 'BYTES':
          d = function (b) {
            return Q(b, f, w);
          };
          break;
        case 'ARRAYBUFFER':
          try {
            g = new ArrayBuffer(0);
          } catch (p) {
            throw Error('ARRAYBUFFER not supported by this environment');
          }
          d = function (b) {
            return R(b, f, w);
          };
          break;
        case 'UINT8ARRAY':
          try {
            g = new Uint8Array(0);
          } catch (p) {
            throw Error('UINT8ARRAY not supported by this environment');
          }
          d = function (b) {
            return S(b, f, w);
          };
          break;
        default:
          throw Error(
            'format must be HEX, B64, BYTES, ARRAYBUFFER, or UINT8ARRAY'
          );
      }
      n = u(h.slice(), l, k, r(m), f);
      for (g = 1; g < t; g += 1)
        !0 === z &&
          0 !== f % 32 &&
          (n[n.length - 1] &= 16777215 >>> (24 - (f % 32))),
          (n = u(n, f, 0, A(e), f));
      return d(n);
    };
    this.getHMAC = function (b, a) {
      var d, g, c, p;
      if (!1 === I)
        throw Error('Cannot call getHMAC without first setting HMAC key');
      c = N(a);
      switch (b) {
        case 'HEX':
          d = function (b) {
            return O(b, f, w, c);
          };
          break;
        case 'B64':
          d = function (b) {
            return P(b, f, w, c);
          };
          break;
        case 'BYTES':
          d = function (b) {
            return Q(b, f, w);
          };
          break;
        case 'ARRAYBUFFER':
          try {
            d = new ArrayBuffer(0);
          } catch (v) {
            throw Error('ARRAYBUFFER not supported by this environment');
          }
          d = function (b) {
            return R(b, f, w);
          };
          break;
        case 'UINT8ARRAY':
          try {
            d = new Uint8Array(0);
          } catch (v) {
            throw Error('UINT8ARRAY not supported by this environment');
          }
          d = function (b) {
            return S(b, f, w);
          };
          break;
        default:
          throw Error(
            'outputFormat must be HEX, B64, BYTES, ARRAYBUFFER, or UINT8ARRAY'
          );
      }
      g = u(h.slice(), l, k, r(m), f);
      p = q(x, A(e));
      p = u(g, f, n, p, f);
      return d(p);
    };
  }
  function a(a, b) {
    this.a = a;
    this.b = b;
  }
  function T(a, b, d, k) {
    var h, l, g, c, p;
    b = b || [0];
    d = d || 0;
    l = d >>> 3;
    p = -1 === k ? 3 : 0;
    for (h = 0; h < a.length; h += 1)
      (c = h + l),
        (g = c >>> 2),
        b.length <= g && b.push(0),
        (b[g] |= a[h] << (8 * (p + (c % 4) * k)));
    return { value: b, binLen: 8 * a.length + d };
  }
  function O(a, b, d, k) {
    var h = '';
    b /= 8;
    var l, g, c;
    c = -1 === d ? 3 : 0;
    for (l = 0; l < b; l += 1)
      (g = a[l >>> 2] >>> (8 * (c + (l % 4) * d))),
        (h +=
          '0123456789abcdef'.charAt((g >>> 4) & 15) +
          '0123456789abcdef'.charAt(g & 15));
    return k.outputUpper ? h.toUpperCase() : h;
  }
  function P(a, b, d, k) {
    var h = '',
      l = b / 8,
      g,
      c,
      p,
      f;
    f = -1 === d ? 3 : 0;
    for (g = 0; g < l; g += 3)
      for (
        c = g + 1 < l ? a[(g + 1) >>> 2] : 0,
          p = g + 2 < l ? a[(g + 2) >>> 2] : 0,
          p =
            (((a[g >>> 2] >>> (8 * (f + (g % 4) * d))) & 255) << 16) |
            (((c >>> (8 * (f + ((g + 1) % 4) * d))) & 255) << 8) |
            ((p >>> (8 * (f + ((g + 2) % 4) * d))) & 255),
          c = 0;
        4 > c;
        c += 1
      )
        8 * g + 6 * c <= b
          ? (h +=
              'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'.charAt(
                (p >>> (6 * (3 - c))) & 63
              ))
          : (h += k.b64Pad);
    return h;
  }
  function Q(a, b, d) {
    var k = '';
    b /= 8;
    var h, c, g;
    g = -1 === d ? 3 : 0;
    for (h = 0; h < b; h += 1)
      (c = (a[h >>> 2] >>> (8 * (g + (h % 4) * d))) & 255),
        (k += String.fromCharCode(c));
    return k;
  }
  function R(a, b, d) {
    b /= 8;
    var k,
      h = new ArrayBuffer(b),
      c,
      g;
    g = new Uint8Array(h);
    c = -1 === d ? 3 : 0;
    for (k = 0; k < b; k += 1)
      g[k] = (a[k >>> 2] >>> (8 * (c + (k % 4) * d))) & 255;
    return h;
  }
  function S(a, b, d) {
    b /= 8;
    var k,
      h = new Uint8Array(b),
      c;
    c = -1 === d ? 3 : 0;
    for (k = 0; k < b; k += 1)
      h[k] = (a[k >>> 2] >>> (8 * (c + (k % 4) * d))) & 255;
    return h;
  }
  function N(a) {
    var b = { outputUpper: !1, b64Pad: '=', shakeLen: -1 };
    a = a || {};
    b.outputUpper = a.outputUpper || !1;
    !0 === a.hasOwnProperty('b64Pad') && (b.b64Pad = a.b64Pad);
    if (!0 === a.hasOwnProperty('shakeLen')) {
      if (0 !== a.shakeLen % 8) throw Error('shakeLen must be a multiple of 8');
      b.shakeLen = a.shakeLen;
    }
    if ('boolean' !== typeof b.outputUpper)
      throw Error('Invalid outputUpper formatting option');
    if ('string' !== typeof b.b64Pad)
      throw Error('Invalid b64Pad formatting option');
    return b;
  }
  function M(a, b, d) {
    switch (b) {
      case 'UTF8':
      case 'UTF16BE':
      case 'UTF16LE':
        break;
      default:
        throw Error('encoding must be UTF8, UTF16BE, or UTF16LE');
    }
    switch (a) {
      case 'HEX':
        a = function (b, a, e) {
          var g = b.length,
            c,
            p,
            f,
            n,
            q,
            u;
          if (0 !== g % 2)
            throw Error('String of HEX type must be in byte increments');
          a = a || [0];
          e = e || 0;
          q = e >>> 3;
          u = -1 === d ? 3 : 0;
          for (c = 0; c < g; c += 2) {
            p = parseInt(b.substr(c, 2), 16);
            if (isNaN(p))
              throw Error('String of HEX type contains invalid characters');
            n = (c >>> 1) + q;
            for (f = n >>> 2; a.length <= f; ) a.push(0);
            a[f] |= p << (8 * (u + (n % 4) * d));
          }
          return { value: a, binLen: 4 * g + e };
        };
        break;
      case 'TEXT':
        a = function (a, e, c) {
          var g,
            m,
            p = 0,
            f,
            n,
            q,
            u,
            r,
            t;
          e = e || [0];
          c = c || 0;
          q = c >>> 3;
          if ('UTF8' === b)
            for (t = -1 === d ? 3 : 0, f = 0; f < a.length; f += 1)
              for (
                g = a.charCodeAt(f),
                  m = [],
                  128 > g
                    ? m.push(g)
                    : 2048 > g
                      ? (m.push(192 | (g >>> 6)), m.push(128 | (g & 63)))
                      : 55296 > g || 57344 <= g
                        ? m.push(
                            224 | (g >>> 12),
                            128 | ((g >>> 6) & 63),
                            128 | (g & 63)
                          )
                        : ((f += 1),
                          (g =
                            65536 +
                            (((g & 1023) << 10) | (a.charCodeAt(f) & 1023))),
                          m.push(
                            240 | (g >>> 18),
                            128 | ((g >>> 12) & 63),
                            128 | ((g >>> 6) & 63),
                            128 | (g & 63)
                          )),
                  n = 0;
                n < m.length;
                n += 1
              ) {
                r = p + q;
                for (u = r >>> 2; e.length <= u; ) e.push(0);
                e[u] |= m[n] << (8 * (t + (r % 4) * d));
                p += 1;
              }
          else if ('UTF16BE' === b || 'UTF16LE' === b)
            for (
              t = -1 === d ? 2 : 0,
                m =
                  ('UTF16LE' === b && 1 !== d) || ('UTF16LE' !== b && 1 === d),
                f = 0;
              f < a.length;
              f += 1
            ) {
              g = a.charCodeAt(f);
              !0 === m && ((n = g & 255), (g = (n << 8) | (g >>> 8)));
              r = p + q;
              for (u = r >>> 2; e.length <= u; ) e.push(0);
              e[u] |= g << (8 * (t + (r % 4) * d));
              p += 2;
            }
          return { value: e, binLen: 8 * p + c };
        };
        break;
      case 'B64':
        a = function (b, a, e) {
          var c = 0,
            m,
            p,
            f,
            n,
            q,
            u,
            r,
            t;
          if (-1 === b.search(/^[a-zA-Z0-9=+\/]+$/))
            throw Error('Invalid character in base-64 string');
          p = b.indexOf('=');
          b = b.replace(/\=/g, '');
          if (-1 !== p && p < b.length)
            throw Error("Invalid '=' found in base-64 string");
          a = a || [0];
          e = e || 0;
          u = e >>> 3;
          t = -1 === d ? 3 : 0;
          for (p = 0; p < b.length; p += 4) {
            q = b.substr(p, 4);
            for (f = n = 0; f < q.length; f += 1)
              (m =
                'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'.indexOf(
                  q.charAt(f)
                )),
                (n |= m << (18 - 6 * f));
            for (f = 0; f < q.length - 1; f += 1) {
              r = c + u;
              for (m = r >>> 2; a.length <= m; ) a.push(0);
              a[m] |= ((n >>> (16 - 8 * f)) & 255) << (8 * (t + (r % 4) * d));
              c += 1;
            }
          }
          return { value: a, binLen: 8 * c + e };
        };
        break;
      case 'BYTES':
        a = function (b, a, e) {
          var c, m, p, f, n, q;
          a = a || [0];
          e = e || 0;
          p = e >>> 3;
          q = -1 === d ? 3 : 0;
          for (m = 0; m < b.length; m += 1)
            (c = b.charCodeAt(m)),
              (n = m + p),
              (f = n >>> 2),
              a.length <= f && a.push(0),
              (a[f] |= c << (8 * (q + (n % 4) * d)));
          return { value: a, binLen: 8 * b.length + e };
        };
        break;
      case 'ARRAYBUFFER':
        try {
          a = new ArrayBuffer(0);
        } catch (k) {
          throw Error('ARRAYBUFFER not supported by this environment');
        }
        a = function (b, a, e) {
          return T(new Uint8Array(b), a, e, d);
        };
        break;
      case 'UINT8ARRAY':
        try {
          a = new Uint8Array(0);
        } catch (k) {
          throw Error('UINT8ARRAY not supported by this environment');
        }
        a = function (b, a, e) {
          return T(b, a, e, d);
        };
        break;
      default:
        throw Error(
          'format must be HEX, TEXT, B64, BYTES, ARRAYBUFFER, or UINT8ARRAY'
        );
    }
    return a;
  }
  function y(a, b) {
    return (a << b) | (a >>> (32 - b));
  }
  function U(e, b) {
    return 32 < b
      ? ((b -= 32),
        new a((e.b << b) | (e.a >>> (32 - b)), (e.a << b) | (e.b >>> (32 - b))))
      : 0 !== b
        ? new a(
            (e.a << b) | (e.b >>> (32 - b)),
            (e.b << b) | (e.a >>> (32 - b))
          )
        : e;
  }
  function x(a, b) {
    return (a >>> b) | (a << (32 - b));
  }
  function t(e, b) {
    var d = null,
      d = new a(e.a, e.b);
    return (d =
      32 >= b
        ? new a(
            (d.a >>> b) | ((d.b << (32 - b)) & 4294967295),
            (d.b >>> b) | ((d.a << (32 - b)) & 4294967295)
          )
        : new a(
            (d.b >>> (b - 32)) | ((d.a << (64 - b)) & 4294967295),
            (d.a >>> (b - 32)) | ((d.b << (64 - b)) & 4294967295)
          ));
  }
  function V(e, b) {
    var d = null;
    return (d =
      32 >= b
        ? new a(e.a >>> b, (e.b >>> b) | ((e.a << (32 - b)) & 4294967295))
        : new a(0, e.a >>> (b - 32)));
  }
  function ca(a, b, d) {
    return (a & b) ^ (~a & d);
  }
  function da(e, b, d) {
    return new a((e.a & b.a) ^ (~e.a & d.a), (e.b & b.b) ^ (~e.b & d.b));
  }
  function W(a, b, d) {
    return (a & b) ^ (a & d) ^ (b & d);
  }
  function ea(e, b, d) {
    return new a(
      (e.a & b.a) ^ (e.a & d.a) ^ (b.a & d.a),
      (e.b & b.b) ^ (e.b & d.b) ^ (b.b & d.b)
    );
  }
  function fa(a) {
    return x(a, 2) ^ x(a, 13) ^ x(a, 22);
  }
  function ga(e) {
    var b = t(e, 28),
      d = t(e, 34);
    e = t(e, 39);
    return new a(b.a ^ d.a ^ e.a, b.b ^ d.b ^ e.b);
  }
  function ha(a) {
    return x(a, 6) ^ x(a, 11) ^ x(a, 25);
  }
  function ia(e) {
    var b = t(e, 14),
      d = t(e, 18);
    e = t(e, 41);
    return new a(b.a ^ d.a ^ e.a, b.b ^ d.b ^ e.b);
  }
  function ja(a) {
    return x(a, 7) ^ x(a, 18) ^ (a >>> 3);
  }
  function ka(e) {
    var b = t(e, 1),
      d = t(e, 8);
    e = V(e, 7);
    return new a(b.a ^ d.a ^ e.a, b.b ^ d.b ^ e.b);
  }
  function la(a) {
    return x(a, 17) ^ x(a, 19) ^ (a >>> 10);
  }
  function ma(e) {
    var b = t(e, 19),
      d = t(e, 61);
    e = V(e, 6);
    return new a(b.a ^ d.a ^ e.a, b.b ^ d.b ^ e.b);
  }
  function G(a, b) {
    var d = (a & 65535) + (b & 65535);
    return (
      ((((a >>> 16) + (b >>> 16) + (d >>> 16)) & 65535) << 16) | (d & 65535)
    );
  }
  function na(a, b, d, k) {
    var h = (a & 65535) + (b & 65535) + (d & 65535) + (k & 65535);
    return (
      ((((a >>> 16) + (b >>> 16) + (d >>> 16) + (k >>> 16) + (h >>> 16)) &
        65535) <<
        16) |
      (h & 65535)
    );
  }
  function H(a, b, d, k, h) {
    var c = (a & 65535) + (b & 65535) + (d & 65535) + (k & 65535) + (h & 65535);
    return (
      ((((a >>> 16) +
        (b >>> 16) +
        (d >>> 16) +
        (k >>> 16) +
        (h >>> 16) +
        (c >>> 16)) &
        65535) <<
        16) |
      (c & 65535)
    );
  }
  function oa(e, b) {
    var d, k, c;
    d = (e.b & 65535) + (b.b & 65535);
    k = (e.b >>> 16) + (b.b >>> 16) + (d >>> 16);
    c = ((k & 65535) << 16) | (d & 65535);
    d = (e.a & 65535) + (b.a & 65535) + (k >>> 16);
    k = (e.a >>> 16) + (b.a >>> 16) + (d >>> 16);
    return new a(((k & 65535) << 16) | (d & 65535), c);
  }
  function pa(e, b, d, k) {
    var c, l, g;
    c = (e.b & 65535) + (b.b & 65535) + (d.b & 65535) + (k.b & 65535);
    l = (e.b >>> 16) + (b.b >>> 16) + (d.b >>> 16) + (k.b >>> 16) + (c >>> 16);
    g = ((l & 65535) << 16) | (c & 65535);
    c =
      (e.a & 65535) +
      (b.a & 65535) +
      (d.a & 65535) +
      (k.a & 65535) +
      (l >>> 16);
    l = (e.a >>> 16) + (b.a >>> 16) + (d.a >>> 16) + (k.a >>> 16) + (c >>> 16);
    return new a(((l & 65535) << 16) | (c & 65535), g);
  }
  function qa(e, b, d, k, c) {
    var l, g, m;
    l =
      (e.b & 65535) +
      (b.b & 65535) +
      (d.b & 65535) +
      (k.b & 65535) +
      (c.b & 65535);
    g =
      (e.b >>> 16) +
      (b.b >>> 16) +
      (d.b >>> 16) +
      (k.b >>> 16) +
      (c.b >>> 16) +
      (l >>> 16);
    m = ((g & 65535) << 16) | (l & 65535);
    l =
      (e.a & 65535) +
      (b.a & 65535) +
      (d.a & 65535) +
      (k.a & 65535) +
      (c.a & 65535) +
      (g >>> 16);
    g =
      (e.a >>> 16) +
      (b.a >>> 16) +
      (d.a >>> 16) +
      (k.a >>> 16) +
      (c.a >>> 16) +
      (l >>> 16);
    return new a(((g & 65535) << 16) | (l & 65535), m);
  }
  function B(e, b) {
    return new a(e.a ^ b.a, e.b ^ b.b);
  }
  function A(e) {
    var b = [],
      d;
    if ('SHA-1' === e)
      b = [1732584193, 4023233417, 2562383102, 271733878, 3285377520];
    else if (0 === e.lastIndexOf('SHA-', 0))
      switch (
        ((b = [
          3238371032, 914150663, 812702999, 4144912697, 4290775857, 1750603025,
          1694076839, 3204075428,
        ]),
        (d = [
          1779033703, 3144134277, 1013904242, 2773480762, 1359893119,
          2600822924, 528734635, 1541459225,
        ]),
        e)
      ) {
        case 'SHA-224':
          break;
        case 'SHA-256':
          b = d;
          break;
        case 'SHA-384':
          b = [
            new a(3418070365, b[0]),
            new a(1654270250, b[1]),
            new a(2438529370, b[2]),
            new a(355462360, b[3]),
            new a(1731405415, b[4]),
            new a(41048885895, b[5]),
            new a(3675008525, b[6]),
            new a(1203062813, b[7]),
          ];
          break;
        case 'SHA-512':
          b = [
            new a(d[0], 4089235720),
            new a(d[1], 2227873595),
            new a(d[2], 4271175723),
            new a(d[3], 1595750129),
            new a(d[4], 2917565137),
            new a(d[5], 725511199),
            new a(d[6], 4215389547),
            new a(d[7], 327033209),
          ];
          break;
        default:
          throw Error('Unknown SHA variant');
      }
    else if (0 === e.lastIndexOf('SHA3-', 0) || 0 === e.lastIndexOf('SHAKE', 0))
      for (e = 0; 5 > e; e += 1)
        b[e] = [
          new a(0, 0),
          new a(0, 0),
          new a(0, 0),
          new a(0, 0),
          new a(0, 0),
        ];
    else throw Error('No SHA variants supported');
    return b;
  }
  function K(a, b) {
    var d = [],
      k,
      c,
      l,
      g,
      m,
      p,
      f;
    k = b[0];
    c = b[1];
    l = b[2];
    g = b[3];
    m = b[4];
    for (f = 0; 80 > f; f += 1)
      (d[f] =
        16 > f ? a[f] : y(d[f - 3] ^ d[f - 8] ^ d[f - 14] ^ d[f - 16], 1)),
        (p =
          20 > f
            ? H(y(k, 5), (c & l) ^ (~c & g), m, 1518500249, d[f])
            : 40 > f
              ? H(y(k, 5), c ^ l ^ g, m, 1859775393, d[f])
              : 60 > f
                ? H(y(k, 5), W(c, l, g), m, 2400959708, d[f])
                : H(y(k, 5), c ^ l ^ g, m, 3395469782, d[f])),
        (m = g),
        (g = l),
        (l = y(c, 30)),
        (c = k),
        (k = p);
    b[0] = G(k, b[0]);
    b[1] = G(c, b[1]);
    b[2] = G(l, b[2]);
    b[3] = G(g, b[3]);
    b[4] = G(m, b[4]);
    return b;
  }
  function ba(a, b, d, c) {
    var h;
    for (h = (((b + 65) >>> 9) << 4) + 15; a.length <= h; ) a.push(0);
    a[b >>> 5] |= 128 << (24 - (b % 32));
    b += d;
    a[h] = b & 4294967295;
    a[h - 1] = (b / 4294967296) | 0;
    b = a.length;
    for (h = 0; h < b; h += 16) c = K(a.slice(h, h + 16), c);
    return c;
  }
  function L(e, b, d) {
    var k,
      h,
      l,
      g,
      m,
      p,
      f,
      n,
      q,
      u,
      r,
      t,
      v,
      x,
      y,
      A,
      z,
      w,
      F,
      B,
      C,
      D,
      E = [],
      J;
    if ('SHA-224' === d || 'SHA-256' === d)
      (u = 64),
        (t = 1),
        (D = Number),
        (v = G),
        (x = na),
        (y = H),
        (A = ja),
        (z = la),
        (w = fa),
        (F = ha),
        (C = W),
        (B = ca),
        (J = c);
    else if ('SHA-384' === d || 'SHA-512' === d)
      (u = 80),
        (t = 2),
        (D = a),
        (v = oa),
        (x = pa),
        (y = qa),
        (A = ka),
        (z = ma),
        (w = ga),
        (F = ia),
        (C = ea),
        (B = da),
        (J = X);
    else throw Error('Unexpected error in SHA-2 implementation');
    d = b[0];
    k = b[1];
    h = b[2];
    l = b[3];
    g = b[4];
    m = b[5];
    p = b[6];
    f = b[7];
    for (r = 0; r < u; r += 1)
      16 > r
        ? ((q = r * t),
          (n = e.length <= q ? 0 : e[q]),
          (q = e.length <= q + 1 ? 0 : e[q + 1]),
          (E[r] = new D(n, q)))
        : (E[r] = x(z(E[r - 2]), E[r - 7], A(E[r - 15]), E[r - 16])),
        (n = y(f, F(g), B(g, m, p), J[r], E[r])),
        (q = v(w(d), C(d, k, h))),
        (f = p),
        (p = m),
        (m = g),
        (g = v(l, n)),
        (l = h),
        (h = k),
        (k = d),
        (d = v(n, q));
    b[0] = v(d, b[0]);
    b[1] = v(k, b[1]);
    b[2] = v(h, b[2]);
    b[3] = v(l, b[3]);
    b[4] = v(g, b[4]);
    b[5] = v(m, b[5]);
    b[6] = v(p, b[6]);
    b[7] = v(f, b[7]);
    return b;
  }
  function D(e, b) {
    var d,
      c,
      h,
      l,
      g = [],
      m = [];
    if (null !== e)
      for (c = 0; c < e.length; c += 2)
        b[(c >>> 1) % 5][((c >>> 1) / 5) | 0] = B(
          b[(c >>> 1) % 5][((c >>> 1) / 5) | 0],
          new a(e[c + 1], e[c])
        );
    for (d = 0; 24 > d; d += 1) {
      l = A('SHA3-');
      for (c = 0; 5 > c; c += 1) {
        h = b[c][0];
        var p = b[c][1],
          f = b[c][2],
          n = b[c][3],
          q = b[c][4];
        g[c] = new a(h.a ^ p.a ^ f.a ^ n.a ^ q.a, h.b ^ p.b ^ f.b ^ n.b ^ q.b);
      }
      for (c = 0; 5 > c; c += 1) m[c] = B(g[(c + 4) % 5], U(g[(c + 1) % 5], 1));
      for (c = 0; 5 > c; c += 1)
        for (h = 0; 5 > h; h += 1) b[c][h] = B(b[c][h], m[c]);
      for (c = 0; 5 > c; c += 1)
        for (h = 0; 5 > h; h += 1)
          l[h][(2 * c + 3 * h) % 5] = U(b[c][h], Y[c][h]);
      for (c = 0; 5 > c; c += 1)
        for (h = 0; 5 > h; h += 1)
          b[c][h] = B(
            l[c][h],
            new a(
              ~l[(c + 1) % 5][h].a & l[(c + 2) % 5][h].a,
              ~l[(c + 1) % 5][h].b & l[(c + 2) % 5][h].b
            )
          );
      b[0][0] = B(b[0][0], Z[d]);
    }
    return b;
  }
  var c, X, Y, Z;
  c = [
    1116352408, 1899447441, 3049323471, 3921009573, 961987163, 1508970993,
    2453635748, 2870763221, 3624381080, 310598401, 607225278, 1426881987,
    1925078388, 2162078206, 2614888103, 3248222580, 3835390401, 4022224774,
    264347078, 604807628, 770255983, 1249150122, 1555081692, 1996064986,
    2554220882, 2821834349, 2952996808, 3210313671, 3336571891, 3584528711,
    113926993, 338241895, 666307205, 773529912, 1294757372, 1396182291,
    1695183700, 1986661051, 2177026350, 2456956037, 2730485921, 2820302411,
    3259730800, 3345764771, 3516065817, 3600352804, 4094571909, 275423344,
    430227734, 506948616, 659060556, 883997877, 958139571, 1322822218,
    1537002063, 1747873779, 1955562222, 2024104815, 2227730452, 2361852424,
    2428436474, 2756734187, 3204031479, 3329325298,
  ];
  X = [
    new a(c[0], 3609767458),
    new a(c[1], 602891725),
    new a(c[2], 3964484399),
    new a(c[3], 2173295548),
    new a(c[4], 4081628472),
    new a(c[5], 3053834265),
    new a(c[6], 2937671579),
    new a(c[7], 3664609560),
    new a(c[8], 2734883394),
    new a(c[9], 1164996542),
    new a(c[10], 1323610764),
    new a(c[11], 3590304994),
    new a(c[12], 4068182383),
    new a(c[13], 991336113),
    new a(c[14], 633803317),
    new a(c[15], 3479774868),
    new a(c[16], 2666613458),
    new a(c[17], 944711139),
    new a(c[18], 2341262773),
    new a(c[19], 2007800933),
    new a(c[20], 1495990901),
    new a(c[21], 1856431235),
    new a(c[22], 3175218132),
    new a(c[23], 2198950837),
    new a(c[24], 3999719339),
    new a(c[25], 766784016),
    new a(c[26], 2566594879),
    new a(c[27], 3203337956),
    new a(c[28], 1034457026),
    new a(c[29], 2466948901),
    new a(c[30], 3758326383),
    new a(c[31], 168717936),
    new a(c[32], 1188179964),
    new a(c[33], 1546045734),
    new a(c[34], 1522805485),
    new a(c[35], 2643833823),
    new a(c[36], 2343527390),
    new a(c[37], 1014477480),
    new a(c[38], 1206759142),
    new a(c[39], 344077627),
    new a(c[40], 1290863460),
    new a(c[41], 3158454273),
    new a(c[42], 3505952657),
    new a(c[43], 106217008),
    new a(c[44], 3606008344),
    new a(c[45], 1432725776),
    new a(c[46], 1467031594),
    new a(c[47], 851169720),
    new a(c[48], 3100823752),
    new a(c[49], 1363258195),
    new a(c[50], 3750685593),
    new a(c[51], 3785050280),
    new a(c[52], 3318307427),
    new a(c[53], 3812723403),
    new a(c[54], 2003034995),
    new a(c[55], 3602036899),
    new a(c[56], 1575990012),
    new a(c[57], 1125592928),
    new a(c[58], 2716904306),
    new a(c[59], 442776044),
    new a(c[60], 593698344),
    new a(c[61], 3733110249),
    new a(c[62], 2999351573),
    new a(c[63], 3815920427),
    new a(3391569614, 3928383900),
    new a(3515267271, 566280711),
    new a(3940187606, 3454069534),
    new a(4118630271, 4000239992),
    new a(116418474, 1914138554),
    new a(174292421, 2731055270),
    new a(289380356, 3203993006),
    new a(460393269, 320620315),
    new a(685471733, 587496836),
    new a(852142971, 1086792851),
    new a(1017036298, 365543100),
    new a(1126000580, 2618297676),
    new a(1288033470, 3409855158),
    new a(1501505948, 4234509866),
    new a(1607167915, 987167468),
    new a(1816402316, 1246189591),
  ];
  Z = [
    new a(0, 1),
    new a(0, 32898),
    new a(2147483648, 32906),
    new a(2147483648, 2147516416),
    new a(0, 32907),
    new a(0, 2147483649),
    new a(2147483648, 2147516545),
    new a(2147483648, 32777),
    new a(0, 138),
    new a(0, 136),
    new a(0, 2147516425),
    new a(0, 2147483658),
    new a(0, 2147516555),
    new a(2147483648, 139),
    new a(2147483648, 32905),
    new a(2147483648, 32771),
    new a(2147483648, 32770),
    new a(2147483648, 128),
    new a(0, 32778),
    new a(2147483648, 2147483658),
    new a(2147483648, 2147516545),
    new a(2147483648, 32896),
    new a(0, 2147483649),
    new a(2147483648, 2147516424),
  ];
  Y = [
    [0, 36, 3, 41, 18],
    [1, 44, 10, 45, 2],
    [62, 6, 43, 15, 61],
    [28, 55, 25, 21, 56],
    [27, 20, 39, 8, 14],
  ];
   true
    ? !(__WEBPACK_AMD_DEFINE_RESULT__ = (function () {
        return C;
      }).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__))
    : 0;
})(this);


/***/ }),

/***/ "./serializers/index.js":
/*!******************************!*\
  !*** ./serializers/index.js ***!
  \******************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   serializeChatObj: () => (/* reexport safe */ _serialize_chat__WEBPACK_IMPORTED_MODULE_1__.serializeChatObj),
/* harmony export */   serializeContactObj: () => (/* reexport safe */ _serialize_contact__WEBPACK_IMPORTED_MODULE_2__.serializeContactObj),
/* harmony export */   serializeIntroReactions: () => (/* reexport safe */ _serialize_reactions__WEBPACK_IMPORTED_MODULE_6__.serializeIntroReactions),
/* harmony export */   serializeMeObj: () => (/* reexport safe */ _serielize_me__WEBPACK_IMPORTED_MODULE_5__.serializeMeObj),
/* harmony export */   serializeMessageObj: () => (/* reexport safe */ _serialize_message__WEBPACK_IMPORTED_MODULE_0__.serializeMessageObj),
/* harmony export */   serializeProfilePicThumb: () => (/* reexport safe */ _serialize_profile_pic_thumb__WEBPACK_IMPORTED_MODULE_3__.serializeProfilePicThumb),
/* harmony export */   serializeRawObj: () => (/* reexport safe */ _serialize_raw__WEBPACK_IMPORTED_MODULE_4__.serializeRawObj),
/* harmony export */   serializeReactions: () => (/* reexport safe */ _serialize_reactions__WEBPACK_IMPORTED_MODULE_6__.serializeReactions)
/* harmony export */ });
/* harmony import */ var _serialize_message__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./serialize-message */ "./serializers/serialize-message.js");
/* harmony import */ var _serialize_chat__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./serialize-chat */ "./serializers/serialize-chat.js");
/* harmony import */ var _serialize_contact__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./serialize-contact */ "./serializers/serialize-contact.js");
/* harmony import */ var _serialize_profile_pic_thumb__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./serialize-profile-pic-thumb */ "./serializers/serialize-profile-pic-thumb.js");
/* harmony import */ var _serialize_raw__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./serialize-raw */ "./serializers/serialize-raw.js");
/* harmony import */ var _serielize_me__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./serielize-me */ "./serializers/serielize-me.js");
/* harmony import */ var _serialize_reactions__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./serialize-reactions */ "./serializers/serialize-reactions.js");









/***/ }),

/***/ "./serializers/serialize-chat.js":
/*!***************************************!*\
  !*** ./serializers/serialize-chat.js ***!
  \***************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   serializeChatObj: () => (/* binding */ serializeChatObj)
/* harmony export */ });
/**
 * Serializes a chat object
 * @param rawChat Chat object
 * @returns {Chat}
 */
const serializeChatObj = (obj) => {
  if (obj == undefined) {
    return null;
  }
  return Object.assign(API.serializeRawObj(obj), {
    kind: obj?.kind,
    isGroup: obj?.isGroup,
    contact: obj?.contact ? API.serializeContactObj(obj?.contact) : null,
    groupMetadata: obj?.groupMetadata
      ? API.serializeRawObj(obj?.groupMetadata)
      : null,
    presence: obj?.presence ? API.serializeRawObj(obj?.presence) : null,
    msgs: null,
    tcToken: null,
    isOnline: obj?.__x_presence?.attributes?.isOnline,
    lastSeen: obj?.previewMessage?.__x_ephemeralStartTimestamp
      ? obj.previewMessage.__x_ephemeralStartTimestamp * 1000
      : null,
  });
};


/***/ }),

/***/ "./serializers/serialize-contact.js":
/*!******************************************!*\
  !*** ./serializers/serialize-contact.js ***!
  \******************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   serializeContactObj: () => (/* binding */ serializeContactObj)
/* harmony export */ });
/**
 * Function to serialize contact object
 * @param {*} obj
 * @returns
 */
const serializeContactObj = (obj) => {
  if (obj == undefined) {
    return null;
  }

  if (!obj.profilePicThumb && obj.id && Store.ProfilePicThumb) {
    obj.profilePicThumb = Store.ProfilePicThumb.get(obj.id);
  }

  return Object.assign(window.API.serializeRawObj(obj), {
    revisionNumber: obj?.revisionNumber,
    is_contact: obj?.isAddressBookContact,
    profilePicThumbObj: obj?.profilePicThumb
      ? API.serializeProfilePicThumb(obj?.profilePicThumb)
      : {},
    isBusiness: obj?.isBusiness,
    isEnterprise: obj?.isEnterprise,
    isSmb: obj?.isSmb,
    labels: obj?.labels,
    locale: obj?.locale,
    name: obj?.name,
    pendingAction: obj?.pendingAction,
    shortName: obj?.shortName,
    verifiedName: obj?.verifiedName,
  });
};


/***/ }),

/***/ "./serializers/serialize-message.js":
/*!******************************************!*\
  !*** ./serializers/serialize-message.js ***!
  \******************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   serializeMessageObj: () => (/* binding */ serializeMessageObj)
/* harmony export */ });
/**
 * Function to serialize a message object
 * @param {*} obj
 * @param {*} groupInfo
 * @returns
 */
const serializeMessageObj = async (obj, groupInfo = true) => {
  if (obj === undefined) {
    return null;
  }

  let objGroup = null;
  if (groupInfo) {
    let chats = await API.getAllChats();
    if (chats) {
      objGroup =
        obj?.to?.server === 'g.us' || obj?.from?.server === 'g.us'
          ? chats.find(
              (chat) => chat?.id?._serialized === obj?.from?._serialized
            ).contact
          : null;
    }
  }

  const obkAds = {
    conversionSource: obj?.ctwaContext?.conversionSource,
    description: obj?.ctwaContext?.description,
    isSuspiciousLink: obj?.ctwaContext?.isSuspiciousLink,
    mediaType: obj?.ctwaContext?.mediaType,
    mediaUrl: obj?.ctwaContext?.mediaUrl,
    sourceUrl: obj?.ctwaContext?.sourceUrl,
    thumbnail: obj?.ctwaContext?.thumbnail,
    thumbnailUrl: obj?.ctwaContext?.thumbnailUrl,
    title: obj?.ctwaContext?.title,
  };

  const _chat = obj?.chat ? await API.serializeChatObj(obj?.chat) : {};

  const isMedia =
    obj.clientUrl !== undefined ? obj.clientUrl : obj.deprecatedMms3Url;

  const quotedStanzaId = obj?.quotedStanzaID || obj?.quotedStanzaID;

  if (obj?.quotedMsg && obj?.quotedMsg.messageSecret) {
    obj.quotedMsg.messageSecret = null;
  }

  return {
    ...window.API.serializeRawObj(obj),
    id: obj?.id?._serialized,
    msgKey: obj?.id,
    from: obj?.from?._serialized,
    quotedParticipant:
      obj?.quotedParticipant?._serialized ||
      obj?.quotedParticipant?._serialized,
    author: obj?.author?._serialized || obj?.author?._serialized,
    chatId: obj?.id?.remote || obj?.chatId?._serialized,
    to: obj?.to?._serialized,
    fromMe: obj?.id?.fromMe,
    sender: obj?.senderObj
      ? await API.serializeContactObj(obj?.senderObj)
      : null,
    timestamp: obj?.t,
    description: obj?.description,
    content: obj?.body,
    body: obj?.body,
    isLink: obj?.isLink,
    isMedia: isMedia ? true : false,
    isNotification: obj?.isNotification,
    isPSA: obj?.isPSA,
    type: obj?.type,
    chat: _chat,
    isOnline: _chat?.isOnline,
    lastSeen: _chat?.lastSeen,
    quotedMsgObj: obj?.quotedMsg,
    quotedStanzaId: quotedStanzaId,
    mediaData: API.serializeRawObj(obj?.mediaData),
    caption: obj?.caption,
    deprecatedMms3Url: obj?.deprecatedMms3Url,
    directPath: obj?.directPath,
    encFilehash: obj?.encFilehash,
    filehash: obj?.filehash,
    filename: obj?.filename,
    mimetype: obj?.mimetype,
    clientUrl: obj?.clientUrl,
    mediaKey: obj?.mediaKey,
    size: obj?.size,
    t: obj?.t,
    isNewMsg: obj?.isNewMsg,
    linkPreview: obj?.linkPreview,
    text: obj?.text,
    height: obj?.height,
    width: obj?.width,
    self: obj?.self,
    initialPageSize: obj?.initialPageSize,
    lat: obj?.lat,
    lng: obj?.lng,
    ack: obj?.ack,
    scanLengths: null,
    scansSidecar: null,
    streamingSidecar: null,
    waveform: null,
    replyButtons: obj?.replyButtons,
    dynamicReplyButtons: obj?.dynamicReplyButtons,
    buttons: obj?.buttons,
    hydratedButtons: obj?.hydratedButtons,
    subtype: obj?.subtype,
    thumbnail: obj?.thumbnail,
    isGroupMsg: obj?.to?.server === 'g.us' || obj?.from?.server === 'g.us',
    groupInfo: objGroup,
    title: obj?.title,
    ctwaContext: obj?.ctwaContext || obkAds,
    messageSecret: null,
  };
};


/***/ }),

/***/ "./serializers/serialize-profile-pic-thumb.js":
/*!****************************************************!*\
  !*** ./serializers/serialize-profile-pic-thumb.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   serializeProfilePicThumb: () => (/* binding */ serializeProfilePicThumb)
/* harmony export */ });
/**
 * Function to serialize the profile pic thumb
 * @param {*} obj
 * @returns
 */
const serializeProfilePicThumb = (obj) => {
  if (obj == undefined) {
    return null;
  }

  return Object.assign(
    {},
    {
      eurl: obj.eurl,
      id: obj.id,
      img: obj.img,
      imgFull: obj.imgFull,
      raw: obj.raw,
      tag: obj.tag,
    }
  );
};


/***/ }),

/***/ "./serializers/serialize-raw.js":
/*!**************************************!*\
  !*** ./serializers/serialize-raw.js ***!
  \**************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   serializeRawObj: () => (/* binding */ serializeRawObj)
/* harmony export */ });
/**
 * Function to serialize raw object
 * @param {*} obj
 * @returns
 */
const serializeRawObj = (obj) => {
  if (obj && obj.toJSON) {
    obj.waveform = null;
    return obj.toJSON();
  }
  return {};
};


/***/ }),

/***/ "./serializers/serialize-reactions.js":
/*!********************************************!*\
  !*** ./serializers/serialize-reactions.js ***!
  \********************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   serializeIntroReactions: () => (/* binding */ serializeIntroReactions),
/* harmony export */   serializeReactions: () => (/* binding */ serializeReactions)
/* harmony export */ });
const validateObject = (obj, name) => {
  if (!obj || typeof obj !== 'object') {
    throw new Error(`Invalid ${name} object`);
  }
};

const mapSender = (sender) => ({
  msgKey: sender?.msgKey ?? null,
  read: sender?.read ?? false,
  senderUserJid: sender?.senderUserJid ?? null,
  timestamp: sender?.timestamp ?? null,
  reactionText: sender?.reactionText ?? '',
  parentMsgKey: sender?.parentMsgKey ?? null,
  orphan: sender?.orphan ?? false,
  isSendFailure: sender?.isSendFailure ?? false,
  isFailed: sender?.isFailed ?? false,
  id: sender?.id ?? null,
  ack: sender?.ack ?? 0,
});

const getInfoSender = async (collections) => {
  validateObject(collections, 'collections');

  return Object.values(collections)
    .filter((coll) => coll?.senders?._index)
    .map((coll) => {
      const senders = Object.values(coll.senders._index).map(mapSender);
      return {
        aggregateEmoji: coll.__x_aggregateEmoji ?? null,
        hasReactionByMe: coll.__x_hasReactionByMe ?? false,
        sender: senders,
      };
    });
};

/**
 * Function to serialize reactions
 */
const serializeReactions = async (emoji, collections, type) => {
  validateObject(emoji, 'emoji');
  validateObject(collections, 'collections');
  validateObject(type, 'type');

  const typeReaction = type.add ? 'add' : 'remove';
  const senders = collections._index
    ? await getInfoSender(collections._index)
    : [];

  return {
    hasReactionByMe: emoji.__x_hasReactionByMe ?? null,
    aggregateEmoji: emoji.__x_aggregateEmoji ?? null,
    id: collections?.parent?.__x_id ?? null,
    index: collections._index ? Object.keys(collections._index) : null,
    typeReaction,
    senders,
  };
};

/**
 * Serialize intro reactions
 */
const serializeIntroReactions = async (emoji, type) => {
  validateObject(emoji, 'emoji');
  validateObject(type, 'type');

  const sendersIndex = emoji?.reactions?._index;

  const senders = sendersIndex ? await getInfoSender(sendersIndex) : [];
  const reactionByMe = emoji?.__x_reactionByMe;
  const index = sendersIndex ? Object.keys(sendersIndex) : null;
  if (!index.length) {
    return [];
  }
  return {
    id: emoji?.__x_id,
    senders,
    reactionByMe: {
      ack: reactionByMe?.ack,
      msgKey: reactionByMe?.msgKey,
      orphan: reactionByMe?.orphan,
      parentMsgKey: reactionByMe?.parentMsgKey,
      reactionText: reactionByMe?.reactionText,
      read: reactionByMe?.read,
      senderUserJid: reactionByMe?.senderUserJid,
      timestamp: reactionByMe?.timestamp,
    },
    index,
    typeReaction: 'add',
  };
};


/***/ }),

/***/ "./serializers/serielize-me.js":
/*!*************************************!*\
  !*** ./serializers/serielize-me.js ***!
  \*************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   serializeMeObj: () => (/* binding */ serializeMeObj)
/* harmony export */ });
/**
 * Function to serialize the me object
 * @param {*} obj
 * @returns
 */
const serializeMeObj = async (obj) => {
  if (obj == undefined) {
    return null;
  }
  const newObj = {};
  const infoMe = Store?.Conn;
  const profilePicThumb = obj?.profilePicThumb?.attributes;
  Object.assign(newObj, {
    id: obj?.id,
    platform: infoMe?.platform,
    name: obj?.name,
    shortName: obj?.shortName,
    isBusiness: obj?.isBusiness,
    pushname: infoMe?.pushname,
    eurl: profilePicThumb?.eurl,
    filehash: profilePicThumb?.filehash,
    fullDirectPath: profilePicThumb?.fullDirectPath,
    previewDirectPath: profilePicThumb?.previewDirectPath,
    previewEurl: profilePicThumb?.previewEurl,
    timestamp: profilePicThumb?.timestamp,
    ips: profilePicThumb?.lastHostUsed?.ips,
    status: obj?.status?.status,
  });
  return newObj;
};


/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/compat get default export */
/******/ 	(() => {
/******/ 		// getDefaultExport function for compatibility with non-harmony modules
/******/ 		__webpack_require__.n = (module) => {
/******/ 			var getter = module && module.__esModule ?
/******/ 				() => (module['default']) :
/******/ 				() => (module);
/******/ 			__webpack_require__.d(getter, { a: getter });
/******/ 			return getter;
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/define property getters */
/******/ 	(() => {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = (exports, definition) => {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	(() => {
/******/ 		__webpack_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ 	})();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	(() => {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = (exports) => {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	})();
/******/ 	
/************************************************************************/
var __webpack_exports__ = {};
// This entry needs to be wrapped in an IIFE because it needs to be isolated against other modules in the chunk.
(() => {
/*!****************!*\
  !*** ./api.js ***!
  \****************/
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _help__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./help */ "./help/index.js");
/* harmony import */ var _functions_help__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./functions/help */ "./functions/help/index.js");
/* harmony import */ var _functions__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./functions */ "./functions/index.js");
/* harmony import */ var _serializers__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./serializers */ "./serializers/index.js");
/* harmony import */ var _init_parasite__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./init-parasite */ "./init-parasite.js");










(0,_init_parasite__WEBPACK_IMPORTED_MODULE_4__.initParasite)();

if (typeof window.API === 'undefined') {
  window.API = {};

  // Helps Functions
  window.API.getChat = _functions_help__WEBPACK_IMPORTED_MODULE_1__.getChat;
  window.API.scope = _functions_help__WEBPACK_IMPORTED_MODULE_1__.scope;
  window.API.getNewId = _functions_help__WEBPACK_IMPORTED_MODULE_1__.getNewId;
  window.API.getNewMessageId = _functions_help__WEBPACK_IMPORTED_MODULE_1__.getNewMessageId;
  window.API.sendExist = _functions_help__WEBPACK_IMPORTED_MODULE_1__.sendExist;
  window.API.checkNumberStatus = _functions_help__WEBPACK_IMPORTED_MODULE_1__.checkNumberStatus;
  window.API.isMD = _functions_help__WEBPACK_IMPORTED_MODULE_1__.isMD;
  window.API.baseSendMessage = _functions__WEBPACK_IMPORTED_MODULE_2__.baseSendMessage;
  window.API.processFiles = _help__WEBPACK_IMPORTED_MODULE_0__.processFiles;
  window.API.base64ToFile = _help__WEBPACK_IMPORTED_MODULE_0__.base64ToFile;
  window.API.generateMediaKey = _help__WEBPACK_IMPORTED_MODULE_0__.generateMediaKey;
  window.API.arrayBufferToBase64 = _help__WEBPACK_IMPORTED_MODULE_0__.arrayBufferToBase64;
  window.API.encryptAndUploadFile = _help__WEBPACK_IMPORTED_MODULE_0__.encryptAndUploadFile;
  window.API.getFileHash = _help__WEBPACK_IMPORTED_MODULE_0__.getFileHash;
  window.API.sendCheckType = _functions_help__WEBPACK_IMPORTED_MODULE_1__.sendCheckType;
  window.API.returnChat = _functions_help__WEBPACK_IMPORTED_MODULE_1__.returnChat;
  window.API.checkChatExist = _functions_help__WEBPACK_IMPORTED_MODULE_1__.checkChatExist;

  // Send Functions
  window.API.sendMessage = _functions__WEBPACK_IMPORTED_MODULE_2__.sendMessage;

  // Host Functions
  window.API.getAllContacts = _functions__WEBPACK_IMPORTED_MODULE_2__.getAllContacts;
  window.API.getHost = _functions__WEBPACK_IMPORTED_MODULE_2__.getHost;
  window.API.getAllChats = _functions__WEBPACK_IMPORTED_MODULE_2__.getAllChats;
  window.API.getContact = _functions__WEBPACK_IMPORTED_MODULE_2__.getContact;
  window.API.getWAVersion = _functions__WEBPACK_IMPORTED_MODULE_2__.getWAVersion;

  // Group Functions
  window.API.createGroup = _functions__WEBPACK_IMPORTED_MODULE_2__.createGroup;
  window.API.addParticipant = _functions__WEBPACK_IMPORTED_MODULE_2__.addParticipant;
  window.API.setGroupDescription = _functions__WEBPACK_IMPORTED_MODULE_2__.setGroupDescription;
  window.API.setGroupImage = _functions__WEBPACK_IMPORTED_MODULE_2__.setGroupImage;

  // Serialize Functions
  window.API.serializeMessageObj = _serializers__WEBPACK_IMPORTED_MODULE_3__.serializeMessageObj;
  window.API.serializeChatObj = _serializers__WEBPACK_IMPORTED_MODULE_3__.serializeChatObj;
  window.API.serializeContactObj = _serializers__WEBPACK_IMPORTED_MODULE_3__.serializeContactObj;
  window.API.serializeProfilePicThumb = _serializers__WEBPACK_IMPORTED_MODULE_3__.serializeProfilePicThumb;
  window.API.serializeRawObj = _serializers__WEBPACK_IMPORTED_MODULE_3__.serializeRawObj;
  window.API.serializeMeObj = _serializers__WEBPACK_IMPORTED_MODULE_3__.serializeMeObj;
  window.API.serializeReactions = _serializers__WEBPACK_IMPORTED_MODULE_3__.serializeReactions;
  window.API.serializeIntroReactions = _serializers__WEBPACK_IMPORTED_MODULE_3__.serializeIntroReactions;
}

})();

/******/ })()
;
//# sourceMappingURL=api.js.map